/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtDataVisualizationAPI_H
#define _QtDataVisualizationAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_TIMELINE_QtDataVisualization_6_11_0
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QItemModelSurfaceDataProxy__MultiMatchBehavior 0
#define sipName_QItemModelSurfaceDataProxy__MultiMatchBehavior &sipStrings_QtDataVisualization[0]
#define sipNameNr_47 47
#define sipName_47 &sipStrings_QtDataVisualization[47]
#define sipNameNr_QItemModelBarDataProxy__MultiMatchBehavior 90
#define sipName_QItemModelBarDataProxy__MultiMatchBehavior &sipStrings_QtDataVisualization[90]
#define sipNameNr_133 133
#define sipName_133 &sipStrings_QtDataVisualization[133]
#define sipNameNr_PYQT_DATAVISUALIZATION_VERSION_STR 173
#define sipName_PYQT_DATAVISUALIZATION_VERSION_STR &sipStrings_QtDataVisualization[173]
#define sipNameNr_QAbstract3DGraph__OptimizationHint 208
#define sipName_QAbstract3DGraph__OptimizationHint &sipStrings_QtDataVisualization[208]
#define sipNameNr_QAbstract3DInputHandler__InputView 243
#define sipName_QAbstract3DInputHandler__InputView &sipStrings_QtDataVisualization[243]
#define sipNameNr_278 278
#define sipName_278 &sipStrings_QtDataVisualization[278]
#define sipNameNr_QAbstract3DAxis__AxisOrientation 313
#define sipName_QAbstract3DAxis__AxisOrientation &sipStrings_QtDataVisualization[313]
#define sipNameNr_QAbstract3DGraph__SelectionFlag 346
#define sipName_QAbstract3DGraph__SelectionFlag &sipStrings_QtDataVisualization[346]
#define sipNameNr_QAbstract3DGraph__ShadowQuality 378
#define sipName_QAbstract3DGraph__ShadowQuality &sipStrings_QtDataVisualization[378]
#define sipNameNr_410 410
#define sipName_410 &sipStrings_QtDataVisualization[410]
#define sipNameNr_442 442
#define sipName_442 &sipStrings_QtDataVisualization[442]
#define sipNameNr_CameraPresetDirectlyAboveCCW45 474
#define sipName_CameraPresetDirectlyAboveCCW45 &sipStrings_QtDataVisualization[474]
#define sipNameNr_CameraPresetIsometricRightHigh 505
#define sipName_CameraPresetIsometricRightHigh &sipStrings_QtDataVisualization[505]
#define sipNameNr_PYQT_DATAVISUALIZATION_VERSION 536
#define sipName_PYQT_DATAVISUALIZATION_VERSION &sipStrings_QtDataVisualization[536]
#define sipNameNr_singleHighlightGradientChanged 567
#define sipName_singleHighlightGradientChanged &sipStrings_QtDataVisualization[567]
#define sipNameNr_CameraPresetDirectlyAboveCW45 598
#define sipName_CameraPresetDirectlyAboveCW45 &sipStrings_QtDataVisualization[598]
#define sipNameNr_CameraPresetIsometricLeftHigh 628
#define sipName_CameraPresetIsometricLeftHigh &sipStrings_QtDataVisualization[628]
#define sipNameNr_QAbstract3DGraph__ElementType 658
#define sipName_QAbstract3DGraph__ElementType &sipStrings_QtDataVisualization[658]
#define sipNameNr_QAbstract3DSeries__SeriesType 688
#define sipName_QAbstract3DSeries__SeriesType &sipStrings_QtDataVisualization[688]
#define sipNameNr_highlightLightStrengthChanged 718
#define sipName_highlightLightStrengthChanged &sipStrings_QtDataVisualization[718]
#define sipNameNr_labelBackgroundEnabledChanged 748
#define sipName_labelBackgroundEnabledChanged &sipStrings_QtDataVisualization[748]
#define sipNameNr_multiHighlightGradientChanged 778
#define sipName_multiHighlightGradientChanged &sipStrings_QtDataVisualization[778]
#define sipNameNr_selectionQueryPositionChanged 808
#define sipName_selectionQueryPositionChanged &sipStrings_QtDataVisualization[808]
#define sipNameNr_QAbstractDataProxy__DataType 838
#define sipName_QAbstractDataProxy__DataType &sipStrings_QtDataVisualization[838]
#define sipNameNr_horizontalAspectRatioChanged 867
#define sipName_horizontalAspectRatioChanged &sipStrings_QtDataVisualization[867]
#define sipNameNr_secondarySubviewOnTopChanged 896
#define sipName_secondarySubviewOnTopChanged &sipStrings_QtDataVisualization[896]
#define sipNameNr_sliceFrameThicknessesChanged 925
#define sipName_sliceFrameThicknessesChanged &sipStrings_QtDataVisualization[925]
#define sipNameNr_954 954
#define sipName_954 &sipStrings_QtDataVisualization[954]
#define sipNameNr_ambientLightStrengthChanged 982
#define sipName_ambientLightStrengthChanged &sipStrings_QtDataVisualization[982]
#define sipNameNr_autoColumnCategoriesChanged 1010
#define sipName_autoColumnCategoriesChanged &sipStrings_QtDataVisualization[1010]
#define sipNameNr_flatShadingSupportedChanged 1038
#define sipName_flatShadingSupportedChanged &sipStrings_QtDataVisualization[1038]
#define sipNameNr_labelBackgroundColorChanged 1066
#define sipName_labelBackgroundColorChanged &sipStrings_QtDataVisualization[1066]
#define sipNameNr_queriedGraphPositionChanged 1094
#define sipName_queriedGraphPositionChanged &sipStrings_QtDataVisualization[1094]
#define sipNameNr_secondarySubViewportChanged 1122
#define sipName_secondarySubViewportChanged &sipStrings_QtDataVisualization[1122]
#define sipNameNr_singleHighlightColorChanged 1150
#define sipName_singleHighlightColorChanged &sipStrings_QtDataVisualization[1150]
#define sipNameNr_CameraPresetIsometricRight 1178
#define sipName_CameraPresetIsometricRight &sipStrings_QtDataVisualization[1178]
#define sipNameNr_QHeightMapSurfaceDataProxy 1205
#define sipName_QHeightMapSurfaceDataProxy &sipStrings_QtDataVisualization[1205]
#define sipNameNr_QItemModelScatterDataProxy 1232
#define sipName_QItemModelScatterDataProxy &sipStrings_QtDataVisualization[1232]
#define sipNameNr_QItemModelSurfaceDataProxy 1259
#define sipName_QItemModelSurfaceDataProxy &sipStrings_QtDataVisualization[1259]
#define sipNameNr_QSurface3DSeries__DrawFlag 1286
#define sipName_QSurface3DSeries__DrawFlag &sipStrings_QtDataVisualization[1286]
#define sipNameNr_itemLabelVisibilityChanged 1313
#define sipName_itemLabelVisibilityChanged &sipStrings_QtDataVisualization[1313]
#define sipNameNr_multiHighlightColorChanged 1340
#define sipName_multiHighlightColorChanged &sipStrings_QtDataVisualization[1340]
#define sipNameNr_rotationRolePatternChanged 1367
#define sipName_rotationRolePatternChanged &sipStrings_QtDataVisualization[1367]
#define sipNameNr_rotationRoleReplaceChanged 1394
#define sipName_rotationRoleReplaceChanged &sipStrings_QtDataVisualization[1394]
#define sipNameNr_setSingleHighlightGradient 1421
#define sipName_setSingleHighlightGradient &sipStrings_QtDataVisualization[1421]
#define sipNameNr_zoomAtTargetEnabledChanged 1448
#define sipName_zoomAtTargetEnabledChanged &sipStrings_QtDataVisualization[1448]
#define sipNameNr_CameraPresetDirectlyAbove 1475
#define sipName_CameraPresetDirectlyAbove &sipStrings_QtDataVisualization[1475]
#define sipNameNr_CameraPresetDirectlyBelow 1501
#define sipName_CameraPresetDirectlyBelow &sipStrings_QtDataVisualization[1501]
#define sipNameNr_CameraPresetIsometricLeft 1527
#define sipName_CameraPresetIsometricLeft &sipStrings_QtDataVisualization[1527]
#define sipNameNr_PyQt6_QtDataVisualization 1553
#define sipName_PyQt6_QtDataVisualization &sipStrings_QtDataVisualization[1553]
#define sipNameNr_QAbstract3DAxis__AxisType 1579
#define sipName_QAbstract3DAxis__AxisType &sipStrings_QtDataVisualization[1579]
#define sipNameNr_SelectionItemRowAndColumn 1605
#define sipName_SelectionItemRowAndColumn &sipStrings_QtDataVisualization[1605]
#define sipNameNr_activeInputHandlerChanged 1631
#define sipName_activeInputHandlerChanged &sipStrings_QtDataVisualization[1631]
#define sipNameNr_barSpacingRelativeChanged 1657
#define sipName_barSpacingRelativeChanged &sipStrings_QtDataVisualization[1657]
#define sipNameNr_flatShadingEnabledChanged 1683
#define sipName_flatShadingEnabledChanged &sipStrings_QtDataVisualization[1683]
#define sipNameNr_flipHorizontalGridChanged 1709
#define sipName_flipHorizontalGridChanged &sipStrings_QtDataVisualization[1709]
#define sipNameNr_graphPositionQueryChanged 1735
#define sipName_graphPositionQueryChanged &sipStrings_QtDataVisualization[1735]
#define sipNameNr_isPointInSecondarySubView 1761
#define sipName_isPointInSecondarySubView &sipStrings_QtDataVisualization[1761]
#define sipNameNr_labelBorderEnabledChanged 1787
#define sipName_labelBorderEnabledChanged &sipStrings_QtDataVisualization[1787]
#define sipNameNr_multiMatchBehaviorChanged 1813
#define sipName_multiMatchBehaviorChanged &sipStrings_QtDataVisualization[1813]
#define sipNameNr_multiSeriesUniformChanged 1839
#define sipName_multiSeriesUniformChanged &sipStrings_QtDataVisualization[1839]
#define sipNameNr_primarySubViewportChanged 1865
#define sipName_primarySubViewportChanged &sipStrings_QtDataVisualization[1865]
#define sipNameNr_setHighlightLightStrength 1891
#define sipName_setHighlightLightStrength &sipStrings_QtDataVisualization[1891]
#define sipNameNr_setLabelBackgroundEnabled 1917
#define sipName_setLabelBackgroundEnabled &sipStrings_QtDataVisualization[1917]
#define sipNameNr_setMultiHighlightGradient 1943
#define sipName_setMultiHighlightGradient &sipStrings_QtDataVisualization[1943]
#define sipNameNr_setSelectionQueryPosition 1969
#define sipName_setSelectionQueryPosition &sipStrings_QtDataVisualization[1969]
#define sipNameNr_useModelCategoriesChanged 1995
#define sipName_useModelCategoriesChanged &sipStrings_QtDataVisualization[1995]
#define sipNameNr_ColorStyleObjectGradient 2021
#define sipName_ColorStyleObjectGradient &sipStrings_QtDataVisualization[2021]
#define sipNameNr_2046 2046
#define sipName_2046 &sipStrings_QtDataVisualization[2046]
#define sipNameNr_2071 2071
#define sipName_2071 &sipStrings_QtDataVisualization[2071]
#define sipNameNr_QLogValue3DAxisFormatter 2096
#define sipName_QLogValue3DAxisFormatter &sipStrings_QtDataVisualization[2096]
#define sipNameNr_autoRowCategoriesChanged 2121
#define sipName_autoRowCategoriesChanged &sipStrings_QtDataVisualization[2121]
#define sipNameNr_backgroundEnabledChanged 2146
#define sipName_backgroundEnabledChanged &sipStrings_QtDataVisualization[2146]
#define sipNameNr_columnRolePatternChanged 2171
#define sipName_columnRolePatternChanged &sipStrings_QtDataVisualization[2171]
#define sipNameNr_columnRoleReplaceChanged 2196
#define sipName_columnRoleReplaceChanged &sipStrings_QtDataVisualization[2196]
#define sipNameNr_invalidSelectionPosition 2221
#define sipName_invalidSelectionPosition &sipStrings_QtDataVisualization[2221]
#define sipNameNr_isLabelBackgroundEnabled 2246
#define sipName_isLabelBackgroundEnabled &sipStrings_QtDataVisualization[2246]
#define sipNameNr_labelAutoRotationChanged 2271
#define sipName_labelAutoRotationChanged &sipStrings_QtDataVisualization[2271]
#define sipNameNr_optimizationHintsChanged 2296
#define sipName_optimizationHintsChanged &sipStrings_QtDataVisualization[2296]
#define sipNameNr_radialLabelOffsetChanged 2321
#define sipName_radialLabelOffsetChanged &sipStrings_QtDataVisualization[2321]
#define sipNameNr_setHorizontalAspectRatio 2346
#define sipName_setHorizontalAspectRatio &sipStrings_QtDataVisualization[2346]
#define sipNameNr_setSecondarySubviewOnTop 2371
#define sipName_setSecondarySubviewOnTop &sipStrings_QtDataVisualization[2371]
#define sipNameNr_setSliceFrameThicknesses 2396
#define sipName_setSliceFrameThicknesses &sipStrings_QtDataVisualization[2396]
#define sipNameNr_CameraPresetBehindBelow 2421
#define sipName_CameraPresetBehindBelow &sipStrings_QtDataVisualization[2421]
#define sipNameNr_ColorStyleRangeGradient 2445
#define sipName_ColorStyleRangeGradient &sipStrings_QtDataVisualization[2445]
#define sipNameNr_DrawSurfaceAndWireframe 2469
#define sipName_DrawSurfaceAndWireframe &sipStrings_QtDataVisualization[2469]
#define sipNameNr_PyQt6_sip_simplewrapper 2493
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtDataVisualization[2493]
#define sipNameNr_Q3DCamera__CameraPreset 2517
#define sipName_Q3DCamera__CameraPreset &sipStrings_QtDataVisualization[2517]
#define sipNameNr_QAbstract3DInputHandler 2541
#define sipName_QAbstract3DInputHandler &sipStrings_QtDataVisualization[2541]
#define sipNameNr_QAbstract3DSeries__Mesh 2565
#define sipName_QAbstract3DSeries__Mesh &sipStrings_QtDataVisualization[2565]
#define sipNameNr_2589 2589
#define sipName_2589 &sipStrings_QtDataVisualization[2589]
#define sipNameNr_2613 2613
#define sipName_2613 &sipStrings_QtDataVisualization[2613]
#define sipNameNr_2637 2637
#define sipName_2637 &sipStrings_QtDataVisualization[2637]
#define sipNameNr_ShadowQualitySoftMedium 2661
#define sipName_ShadowQualitySoftMedium &sipStrings_QtDataVisualization[2661]
#define sipNameNr_columnCategoriesChanged 2685
#define sipName_columnCategoriesChanged &sipStrings_QtDataVisualization[2685]
#define sipNameNr_devicePixelRatioChanged 2709
#define sipName_devicePixelRatioChanged &sipStrings_QtDataVisualization[2709]
#define sipNameNr_isPointInPrimarySubView 2733
#define sipName_isPointInPrimarySubView &sipStrings_QtDataVisualization[2733]
#define sipNameNr_isSecondarySubviewOnTop 2757
#define sipName_isSecondarySubviewOnTop &sipStrings_QtDataVisualization[2757]
#define sipNameNr_positionAbsoluteChanged 2781
#define sipName_positionAbsoluteChanged &sipStrings_QtDataVisualization[2781]
#define sipNameNr_selectedCustomItemIndex 2805
#define sipName_selectedCustomItemIndex &sipStrings_QtDataVisualization[2805]
#define sipNameNr_selectionEnabledChanged 2829
#define sipName_selectionEnabledChanged &sipStrings_QtDataVisualization[2829]
#define sipNameNr_setAmbientLightStrength 2853
#define sipName_setAmbientLightStrength &sipStrings_QtDataVisualization[2853]
#define sipNameNr_setAutoColumnCategories 2877
#define sipName_setAutoColumnCategories &sipStrings_QtDataVisualization[2877]
#define sipNameNr_setLabelBackgroundColor 2901
#define sipName_setLabelBackgroundColor &sipStrings_QtDataVisualization[2901]
#define sipNameNr_setRotationAxisAndAngle 2925
#define sipName_setRotationAxisAndAngle &sipStrings_QtDataVisualization[2925]
#define sipNameNr_setSecondarySubViewport 2949
#define sipName_setSecondarySubViewport &sipStrings_QtDataVisualization[2949]
#define sipNameNr_setSingleHighlightColor 2973
#define sipName_setSingleHighlightColor &sipStrings_QtDataVisualization[2973]
#define sipNameNr_singleHighlightGradient 2997
#define sipName_singleHighlightGradient &sipStrings_QtDataVisualization[2997]
#define sipNameNr_sliceFrameWidthsChanged 3021
#define sipName_sliceFrameWidthsChanged &sipStrings_QtDataVisualization[3021]
#define sipNameNr_useHighDefShaderChanged 3045
#define sipName_useHighDefShaderChanged &sipStrings_QtDataVisualization[3045]
#define sipNameNr_valueRolePatternChanged 3069
#define sipName_valueRolePatternChanged &sipStrings_QtDataVisualization[3069]
#define sipNameNr_valueRoleReplaceChanged 3093
#define sipName_valueRoleReplaceChanged &sipStrings_QtDataVisualization[3093]
#define sipNameNr_CameraPresetBehindHigh 3117
#define sipName_CameraPresetBehindHigh &sipStrings_QtDataVisualization[3117]
#define sipNameNr_CameraPresetFrontBelow 3140
#define sipName_CameraPresetFrontBelow &sipStrings_QtDataVisualization[3140]
#define sipNameNr_CameraPresetRightBelow 3163
#define sipName_CameraPresetRightBelow &sipStrings_QtDataVisualization[3163]
#define sipNameNr_QItemModelBarDataProxy 3186
#define sipName_QItemModelBarDataProxy &sipStrings_QtDataVisualization[3186]
#define sipNameNr_3209 3209
#define sipName_3209 &sipStrings_QtDataVisualization[3209]
#define sipNameNr_SelectionItemAndColumn 3232
#define sipName_SelectionItemAndColumn &sipStrings_QtDataVisualization[3232]
#define sipNameNr_alphaMultiplierChanged 3255
#define sipName_alphaMultiplierChanged &sipStrings_QtDataVisualization[3255]
#define sipNameNr_autoAdjustRangeChanged 3278
#define sipName_autoAdjustRangeChanged &sipStrings_QtDataVisualization[3278]
#define sipNameNr_backgroundColorChanged 3301
#define sipName_backgroundColorChanged &sipStrings_QtDataVisualization[3301]
#define sipNameNr_barSeriesMarginChanged 3324
#define sipName_barSeriesMarginChanged &sipStrings_QtDataVisualization[3324]
#define sipNameNr_drawSliceFramesChanged 3347
#define sipName_drawSliceFramesChanged &sipStrings_QtDataVisualization[3347]
#define sipNameNr_highlightLightStrength 3370
#define sipName_highlightLightStrength &sipStrings_QtDataVisualization[3370]
#define sipNameNr_isFlatShadingSupported 3393
#define sipName_isFlatShadingSupported &sipStrings_QtDataVisualization[3393]
#define sipNameNr_itemLabelFormatChanged 3416
#define sipName_itemLabelFormatChanged &sipStrings_QtDataVisualization[3416]
#define sipNameNr_multiHighlightGradient 3439
#define sipName_multiHighlightGradient &sipStrings_QtDataVisualization[3439]
#define sipNameNr_orthoProjectionChanged 3462
#define sipName_orthoProjectionChanged &sipStrings_QtDataVisualization[3462]
#define sipNameNr_preserveOpacityChanged 3485
#define sipName_preserveOpacityChanged &sipStrings_QtDataVisualization[3485]
#define sipNameNr_rotationEnabledChanged 3508
#define sipName_rotationEnabledChanged &sipStrings_QtDataVisualization[3508]
#define sipNameNr_scalingAbsoluteChanged 3531
#define sipName_scalingAbsoluteChanged &sipStrings_QtDataVisualization[3531]
#define sipNameNr_selectedElementChanged 3554
#define sipName_selectedElementChanged &sipStrings_QtDataVisualization[3554]
#define sipNameNr_selectionQueryPosition 3577
#define sipName_selectionQueryPosition &sipStrings_QtDataVisualization[3577]
#define sipNameNr_setMultiHighlightColor 3600
#define sipName_setMultiHighlightColor &sipStrings_QtDataVisualization[3600]
#define sipNameNr_setRotationRolePattern 3623
#define sipName_setRotationRolePattern &sipStrings_QtDataVisualization[3623]
#define sipNameNr_setRotationRoleReplace 3646
#define sipName_setRotationRoleReplace &sipStrings_QtDataVisualization[3646]
#define sipNameNr_setZoomAtTargetEnabled 3669
#define sipName_setZoomAtTargetEnabled &sipStrings_QtDataVisualization[3669]
#define sipNameNr_sliceFrameColorChanged 3692
#define sipName_sliceFrameColorChanged &sipStrings_QtDataVisualization[3692]
#define sipNameNr_subSegmentCountChanged 3715
#define sipName_subSegmentCountChanged &sipStrings_QtDataVisualization[3715]
#define sipNameNr_titleVisibilityChanged 3738
#define sipName_titleVisibilityChanged &sipStrings_QtDataVisualization[3738]
#define sipNameNr_userDefinedMeshChanged 3761
#define sipName_userDefinedMeshChanged &sipStrings_QtDataVisualization[3761]
#define sipNameNr_xPosRolePatternChanged 3784
#define sipName_xPosRolePatternChanged &sipStrings_QtDataVisualization[3784]
#define sipNameNr_xPosRoleReplaceChanged 3807
#define sipName_xPosRoleReplaceChanged &sipStrings_QtDataVisualization[3807]
#define sipNameNr_yPosRolePatternChanged 3830
#define sipName_yPosRolePatternChanged &sipStrings_QtDataVisualization[3830]
#define sipNameNr_yPosRoleReplaceChanged 3853
#define sipName_yPosRoleReplaceChanged &sipStrings_QtDataVisualization[3853]
#define sipNameNr_zPosRolePatternChanged 3876
#define sipName_zPosRolePatternChanged &sipStrings_QtDataVisualization[3876]
#define sipNameNr_zPosRoleReplaceChanged 3899
#define sipName_zPosRoleReplaceChanged &sipStrings_QtDataVisualization[3899]
#define sipNameNr_CameraPresetBehindLow 3922
#define sipName_CameraPresetBehindLow &sipStrings_QtDataVisualization[3922]
#define sipNameNr_CameraPresetFrontHigh 3944
#define sipName_CameraPresetFrontHigh &sipStrings_QtDataVisualization[3944]
#define sipNameNr_CameraPresetLeftBelow 3966
#define sipName_CameraPresetLeftBelow &sipStrings_QtDataVisualization[3966]
#define sipNameNr_CameraPresetRightHigh 3988
#define sipName_CameraPresetRightHigh &sipStrings_QtDataVisualization[3988]
#define sipNameNr_4010 4010
#define sipName_4010 &sipStrings_QtDataVisualization[4010]
#define sipNameNr_QValue3DAxisFormatter 4032
#define sipName_QValue3DAxisFormatter &sipStrings_QtDataVisualization[4032]
#define sipNameNr_SelectionRowAndColumn 4054
#define sipName_SelectionRowAndColumn &sipStrings_QtDataVisualization[4054]
#define sipNameNr_ShadowQualitySoftHigh 4076
#define sipName_ShadowQualitySoftHigh &sipStrings_QtDataVisualization[4076]
#define sipNameNr_horizontalAspectRatio 4098
#define sipName_horizontalAspectRatio &sipStrings_QtDataVisualization[4098]
#define sipNameNr_invalidSelectionIndex 4120
#define sipName_invalidSelectionIndex &sipStrings_QtDataVisualization[4120]
#define sipNameNr_invalidSelectionPoint 4142
#define sipName_invalidSelectionPoint &sipStrings_QtDataVisualization[4142]
#define sipNameNr_isZoomAtTargetEnabled 4164
#define sipName_isZoomAtTargetEnabled &sipStrings_QtDataVisualization[4164]
#define sipNameNr_labelTextColorChanged 4186
#define sipName_labelTextColorChanged &sipStrings_QtDataVisualization[4186]
#define sipNameNr_mouseDoubleClickEvent 4208
#define sipName_mouseDoubleClickEvent &sipStrings_QtDataVisualization[4208]
#define sipNameNr_qDefaultSurfaceFormat 4230
#define sipName_qDefaultSurfaceFormat &sipStrings_QtDataVisualization[4230]
#define sipNameNr_rowRolePatternChanged 4252
#define sipName_rowRolePatternChanged &sipStrings_QtDataVisualization[4252]
#define sipNameNr_rowRoleReplaceChanged 4274
#define sipName_rowRoleReplaceChanged &sipStrings_QtDataVisualization[4274]
#define sipNameNr_selectedSeriesChanged 4296
#define sipName_selectedSeriesChanged &sipStrings_QtDataVisualization[4296]
#define sipNameNr_setActiveInputHandler 4318
#define sipName_setActiveInputHandler &sipStrings_QtDataVisualization[4318]
#define sipNameNr_setBarSpacingRelative 4340
#define sipName_setBarSpacingRelative &sipStrings_QtDataVisualization[4340]
#define sipNameNr_setFlatShadingEnabled 4362
#define sipName_setFlatShadingEnabled &sipStrings_QtDataVisualization[4362]
#define sipNameNr_setFlipHorizontalGrid 4384
#define sipName_setFlipHorizontalGrid &sipStrings_QtDataVisualization[4384]
#define sipNameNr_setGraphPositionQuery 4406
#define sipName_setGraphPositionQuery &sipStrings_QtDataVisualization[4406]
#define sipNameNr_setLabelBorderEnabled 4428
#define sipName_setLabelBorderEnabled &sipStrings_QtDataVisualization[4428]
#define sipNameNr_setMultiMatchBehavior 4450
#define sipName_setMultiMatchBehavior &sipStrings_QtDataVisualization[4450]
#define sipNameNr_setMultiSeriesUniform 4472
#define sipName_setMultiSeriesUniform &sipStrings_QtDataVisualization[4472]
#define sipNameNr_setPrimarySubViewport 4494
#define sipName_setPrimarySubViewport &sipStrings_QtDataVisualization[4494]
#define sipNameNr_setUseModelCategories 4516
#define sipName_setUseModelCategories &sipStrings_QtDataVisualization[4516]
#define sipNameNr_showEdgeLabelsChanged 4538
#define sipName_showEdgeLabelsChanged &sipStrings_QtDataVisualization[4538]
#define sipNameNr_sliceFrameGapsChanged 4560
#define sipName_sliceFrameGapsChanged &sipStrings_QtDataVisualization[4560]
#define sipNameNr_sliceFrameThicknesses 4582
#define sipName_sliceFrameThicknesses &sipStrings_QtDataVisualization[4582]
#define sipNameNr_wireframeColorChanged 4604
#define sipName_wireframeColorChanged &sipStrings_QtDataVisualization[4604]
#define sipNameNr_CameraPresetFrontLow 4626
#define sipName_CameraPresetFrontLow &sipStrings_QtDataVisualization[4626]
#define sipNameNr_CameraPresetLeftHigh 4647
#define sipName_CameraPresetLeftHigh &sipStrings_QtDataVisualization[4647]
#define sipNameNr_CameraPresetRightLow 4668
#define sipName_CameraPresetRightLow &sipStrings_QtDataVisualization[4668]
#define sipNameNr_InputViewOnSecondary 4689
#define sipName_InputViewOnSecondary &sipStrings_QtDataVisualization[4689]
#define sipNameNr_Q3DTheme__ColorStyle 4710
#define sipName_Q3DTheme__ColorStyle &sipStrings_QtDataVisualization[4710]
#define sipNameNr_4731 4731
#define sipName_4731 &sipStrings_QtDataVisualization[4731]
#define sipNameNr_4752 4752
#define sipName_4752 &sipStrings_QtDataVisualization[4752]
#define sipNameNr_4773 4773
#define sipName_4773 &sipStrings_QtDataVisualization[4773]
#define sipNameNr_QTouch3DInputHandler 4794
#define sipName_QTouch3DInputHandler &sipStrings_QtDataVisualization[4794]
#define sipNameNr_SelectionMultiSeries 4815
#define sipName_SelectionMultiSeries &sipStrings_QtDataVisualization[4815]
#define sipNameNr_ShadowQualitySoftLow 4836
#define sipName_ShadowQualitySoftLow &sipStrings_QtDataVisualization[4836]
#define sipNameNr_ambientLightStrength 4857
#define sipName_ambientLightStrength &sipStrings_QtDataVisualization[4857]
#define sipNameNr_autoColumnCategories 4878
#define sipName_autoColumnCategories &sipStrings_QtDataVisualization[4878]
#define sipNameNr_baseGradientsChanged 4899
#define sipName_baseGradientsChanged &sipStrings_QtDataVisualization[4899]
#define sipNameNr_borderEnabledChanged 4920
#define sipName_borderEnabledChanged &sipStrings_QtDataVisualization[4920]
#define sipNameNr_gridLineColorChanged 4941
#define sipName_gridLineColorChanged &sipStrings_QtDataVisualization[4941]
#define sipNameNr_heightMapFileChanged 4962
#define sipName_heightMapFileChanged &sipStrings_QtDataVisualization[4962]
#define sipNameNr_isBarSpacingRelative 4983
#define sipName_isBarSpacingRelative &sipStrings_QtDataVisualization[4983]
#define sipNameNr_isFlatShadingEnabled 5004
#define sipName_isFlatShadingEnabled &sipStrings_QtDataVisualization[5004]
#define sipNameNr_isLabelBorderEnabled 5025
#define sipName_isLabelBorderEnabled &sipStrings_QtDataVisualization[5025]
#define sipNameNr_isMultiSeriesUniform 5046
#define sipName_isMultiSeriesUniform &sipStrings_QtDataVisualization[5046]
#define sipNameNr_labelBackgroundColor 5067
#define sipName_labelBackgroundColor &sipStrings_QtDataVisualization[5067]
#define sipNameNr_lightStrengthChanged 5088
#define sipName_lightStrengthChanged &sipStrings_QtDataVisualization[5088]
#define sipNameNr_primarySeriesChanged 5109
#define sipName_primarySeriesChanged &sipStrings_QtDataVisualization[5109]
#define sipNameNr_queriedGraphPosition 5130
#define sipName_queriedGraphPosition &sipStrings_QtDataVisualization[5130]
#define sipNameNr_rowCategoriesChanged 5151
#define sipName_rowCategoriesChanged &sipStrings_QtDataVisualization[5151]
#define sipNameNr_secondarySubViewport 5172
#define sipName_secondarySubViewport &sipStrings_QtDataVisualization[5172]
#define sipNameNr_selectedPointChanged 5193
#define sipName_selectedPointChanged &sipStrings_QtDataVisualization[5193]
#define sipNameNr_selectionModeChanged 5214
#define sipName_selectionModeChanged &sipStrings_QtDataVisualization[5214]
#define sipNameNr_setAutoRowCategories 5235
#define sipName_setAutoRowCategories &sipStrings_QtDataVisualization[5235]
#define sipNameNr_setBackgroundEnabled 5256
#define sipName_setBackgroundEnabled &sipStrings_QtDataVisualization[5256]
#define sipNameNr_setColumnRolePattern 5277
#define sipName_setColumnRolePattern &sipStrings_QtDataVisualization[5277]
#define sipNameNr_setColumnRoleReplace 5298
#define sipName_setColumnRoleReplace &sipStrings_QtDataVisualization[5298]
#define sipNameNr_setLabelAutoRotation 5319
#define sipName_setLabelAutoRotation &sipStrings_QtDataVisualization[5319]
#define sipNameNr_setOptimizationHints 5340
#define sipName_setOptimizationHints &sipStrings_QtDataVisualization[5340]
#define sipNameNr_setRadialLabelOffset 5361
#define sipName_setRadialLabelOffset &sipStrings_QtDataVisualization[5361]
#define sipNameNr_setTextureDimensions 5382
#define sipName_setTextureDimensions &sipStrings_QtDataVisualization[5382]
#define sipNameNr_shadowCastingChanged 5403
#define sipName_shadowCastingChanged &sipStrings_QtDataVisualization[5403]
#define sipNameNr_shadowQualityChanged 5424
#define sipName_shadowQualityChanged &sipStrings_QtDataVisualization[5424]
#define sipNameNr_singleHighlightColor 5445
#define sipName_singleHighlightColor &sipStrings_QtDataVisualization[5445]
#define sipNameNr_slicingActiveChanged 5466
#define sipName_slicingActiveChanged &sipStrings_QtDataVisualization[5466]
#define sipNameNr_textureFormatChanged 5487
#define sipName_textureFormatChanged &sipStrings_QtDataVisualization[5487]
#define sipNameNr_textureHeightChanged 5508
#define sipName_textureHeightChanged &sipStrings_QtDataVisualization[5508]
#define sipNameNr_wrapXRotationChanged 5529
#define sipName_wrapXRotationChanged &sipStrings_QtDataVisualization[5529]
#define sipNameNr_wrapYRotationChanged 5550
#define sipName_wrapYRotationChanged &sipStrings_QtDataVisualization[5550]
#define sipNameNr_AxisOrientationNone 5571
#define sipName_AxisOrientationNone &sipStrings_QtDataVisualization[5571]
#define sipNameNr_CameraPresetLeftLow 5591
#define sipName_CameraPresetLeftLow &sipStrings_QtDataVisualization[5591]
#define sipNameNr_OptimizationDefault 5611
#define sipName_OptimizationDefault &sipStrings_QtDataVisualization[5611]
#define sipNameNr_5631 5631
#define sipName_5631 &sipStrings_QtDataVisualization[5631]
#define sipNameNr_SelectionItemAndRow 5651
#define sipName_SelectionItemAndRow &sipStrings_QtDataVisualization[5651]
#define sipNameNr_ShadowQualityMedium 5671
#define sipName_ShadowQualityMedium &sipStrings_QtDataVisualization[5671]
#define sipNameNr_activeCameraChanged 5691
#define sipName_activeCameraChanged &sipStrings_QtDataVisualization[5691]
#define sipNameNr_autoPositionChanged 5711
#define sipName_autoPositionChanged &sipStrings_QtDataVisualization[5711]
#define sipNameNr_barThicknessChanged 5731
#define sipName_barThicknessChanged &sipStrings_QtDataVisualization[5731]
#define sipNameNr_baseGradientChanged 5751
#define sipName_baseGradientChanged &sipStrings_QtDataVisualization[5751]
#define sipNameNr_cameraPresetChanged 5771
#define sipName_cameraPresetChanged &sipStrings_QtDataVisualization[5771]
#define sipNameNr_columnCategoryIndex 5791
#define sipName_columnCategoryIndex &sipStrings_QtDataVisualization[5791]
#define sipNameNr_columnLabelsChanged 5811
#define sipName_columnLabelsChanged &sipStrings_QtDataVisualization[5811]
#define sipNameNr_facingCameraChanged 5831
#define sipName_facingCameraChanged &sipStrings_QtDataVisualization[5831]
#define sipNameNr_isBackgroundEnabled 5851
#define sipName_isBackgroundEnabled &sipStrings_QtDataVisualization[5851]
#define sipNameNr_maxZoomLevelChanged 5871
#define sipName_maxZoomLevelChanged &sipStrings_QtDataVisualization[5871]
#define sipNameNr_meshRotationChanged 5891
#define sipName_meshRotationChanged &sipStrings_QtDataVisualization[5891]
#define sipNameNr_minZoomLevelChanged 5911
#define sipName_minZoomLevelChanged &sipStrings_QtDataVisualization[5911]
#define sipNameNr_multiHighlightColor 5931
#define sipName_multiHighlightColor &sipStrings_QtDataVisualization[5931]
#define sipNameNr_reflectivityChanged 5951
#define sipName_reflectivityChanged &sipStrings_QtDataVisualization[5951]
#define sipNameNr_releaseInputHandler 5971
#define sipName_releaseInputHandler &sipStrings_QtDataVisualization[5971]
#define sipNameNr_rotationRoleChanged 5991
#define sipName_rotationRoleChanged &sipStrings_QtDataVisualization[5991]
#define sipNameNr_rotationRolePattern 6011
#define sipName_rotationRolePattern &sipStrings_QtDataVisualization[6011]
#define sipNameNr_rotationRoleReplace 6031
#define sipName_rotationRoleReplace &sipStrings_QtDataVisualization[6031]
#define sipNameNr_segmentCountChanged 6051
#define sipName_segmentCountChanged &sipStrings_QtDataVisualization[6051]
#define sipNameNr_selectedItemChanged 6071
#define sipName_selectedItemChanged &sipStrings_QtDataVisualization[6071]
#define sipNameNr_setColumnCategories 6091
#define sipName_setColumnCategories &sipStrings_QtDataVisualization[6091]
#define sipNameNr_setDevicePixelRatio 6111
#define sipName_setDevicePixelRatio &sipStrings_QtDataVisualization[6111]
#define sipNameNr_setItemLabelVisible 6131
#define sipName_setItemLabelVisible &sipStrings_QtDataVisualization[6131]
#define sipNameNr_setMeshAxisAndAngle 6151
#define sipName_setMeshAxisAndAngle &sipStrings_QtDataVisualization[6151]
#define sipNameNr_setPositionAbsolute 6171
#define sipName_setPositionAbsolute &sipStrings_QtDataVisualization[6171]
#define sipNameNr_setPreviousInputPos 6191
#define sipName_setPreviousInputPos &sipStrings_QtDataVisualization[6191]
#define sipNameNr_setSelectionEnabled 6211
#define sipName_setSelectionEnabled &sipStrings_QtDataVisualization[6211]
#define sipNameNr_setSliceFrameWidths 6231
#define sipName_setSliceFrameWidths &sipStrings_QtDataVisualization[6231]
#define sipNameNr_setUseHighDefShader 6251
#define sipName_setUseHighDefShader &sipStrings_QtDataVisualization[6251]
#define sipNameNr_setValueRolePattern 6271
#define sipName_setValueRolePattern &sipStrings_QtDataVisualization[6271]
#define sipNameNr_setValueRoleReplace 6291
#define sipName_setValueRoleReplace &sipStrings_QtDataVisualization[6291]
#define sipNameNr_textureDepthChanged 6311
#define sipName_textureDepthChanged &sipStrings_QtDataVisualization[6311]
#define sipNameNr_textureWidthChanged 6331
#define sipName_textureWidthChanged &sipStrings_QtDataVisualization[6331]
#define sipNameNr_CameraPresetBehind 6351
#define sipName_CameraPresetBehind &sipStrings_QtDataVisualization[6351]
#define sipNameNr_InputViewOnPrimary 6370
#define sipName_InputViewOnPrimary &sipStrings_QtDataVisualization[6370]
#define sipNameNr_MultiMatchBehavior 28
#define sipName_MultiMatchBehavior &sipStrings_QtDataVisualization[28]
#define sipNameNr_OptimizationStatic 6389
#define sipName_OptimizationStatic &sipStrings_QtDataVisualization[6389]
#define sipNameNr_QAbstractDataProxy 6408
#define sipName_QAbstractDataProxy &sipStrings_QtDataVisualization[6408]
#define sipNameNr_ThemePrimaryColors 6427
#define sipName_ThemePrimaryColors &sipStrings_QtDataVisualization[6427]
#define sipNameNr_activeInputHandler 6446
#define sipName_activeInputHandler &sipStrings_QtDataVisualization[6446]
#define sipNameNr_activeLightChanged 6465
#define sipName_activeLightChanged &sipStrings_QtDataVisualization[6465]
#define sipNameNr_activeThemeChanged 6484
#define sipName_activeThemeChanged &sipStrings_QtDataVisualization[6484]
#define sipNameNr_aspectRatioChanged 6503
#define sipName_aspectRatioChanged &sipStrings_QtDataVisualization[6503]
#define sipNameNr_autoSubGridChanged 6522
#define sipName_autoSubGridChanged &sipStrings_QtDataVisualization[6522]
#define sipNameNr_columnCountChanged 6541
#define sipName_columnCountChanged &sipStrings_QtDataVisualization[6541]
#define sipNameNr_flipHorizontalGrid 6560
#define sipName_flipHorizontalGrid &sipStrings_QtDataVisualization[6560]
#define sipNameNr_graphPositionQuery 6579
#define sipName_graphPositionQuery &sipStrings_QtDataVisualization[6579]
#define sipNameNr_gridEnabledChanged 6598
#define sipName_gridEnabledChanged &sipStrings_QtDataVisualization[6598]
#define sipNameNr_isItemLabelVisible 6617
#define sipName_isItemLabelVisible &sipStrings_QtDataVisualization[6617]
#define sipNameNr_isPositionAbsolute 6636
#define sipName_isPositionAbsolute &sipStrings_QtDataVisualization[6636]
#define sipNameNr_isSelectionEnabled 6655
#define sipName_isSelectionEnabled &sipStrings_QtDataVisualization[6655]
#define sipNameNr_labelFormatChanged 6674
#define sipName_labelFormatChanged &sipStrings_QtDataVisualization[6674]
#define sipNameNr_multiMatchBehavior 6693
#define sipName_multiMatchBehavior &sipStrings_QtDataVisualization[6693]
#define sipNameNr_orientationChanged 6712
#define sipName_orientationChanged &sipStrings_QtDataVisualization[6712]
#define sipNameNr_primarySubViewport 6731
#define sipName_primarySubViewport &sipStrings_QtDataVisualization[6731]
#define sipNameNr_removeCustomItemAt 6750
#define sipName_removeCustomItemAt &sipStrings_QtDataVisualization[6750]
#define sipNameNr_selectedBarChanged 6769
#define sipName_selectedBarChanged &sipStrings_QtDataVisualization[6769]
#define sipNameNr_selectedCustomItem 6788
#define sipName_selectedCustomItem &sipStrings_QtDataVisualization[6788]
#define sipNameNr_selectedLabelIndex 6807
#define sipName_selectedLabelIndex &sipStrings_QtDataVisualization[6807]
#define sipNameNr_setAlphaMultiplier 6826
#define sipName_setAlphaMultiplier &sipStrings_QtDataVisualization[6826]
#define sipNameNr_setAutoAdjustRange 6845
#define sipName_setAutoAdjustRange &sipStrings_QtDataVisualization[6845]
#define sipNameNr_setBackgroundColor 6864
#define sipName_setBackgroundColor &sipStrings_QtDataVisualization[6864]
#define sipNameNr_setBarSeriesMargin 6883
#define sipName_setBarSeriesMargin &sipStrings_QtDataVisualization[6883]
#define sipNameNr_setDrawSliceFrames 6902
#define sipName_setDrawSliceFrames &sipStrings_QtDataVisualization[6902]
#define sipNameNr_setItemLabelFormat 6921
#define sipName_setItemLabelFormat &sipStrings_QtDataVisualization[6921]
#define sipNameNr_setOrthoProjection 6940
#define sipName_setOrthoProjection &sipStrings_QtDataVisualization[6940]
#define sipNameNr_setPreserveOpacity 6959
#define sipName_setPreserveOpacity &sipStrings_QtDataVisualization[6959]
#define sipNameNr_setRotationEnabled 6978
#define sipName_setRotationEnabled &sipStrings_QtDataVisualization[6978]
#define sipNameNr_setScalingAbsolute 6997
#define sipName_setScalingAbsolute &sipStrings_QtDataVisualization[6997]
#define sipNameNr_setSliceFrameColor 7016
#define sipName_setSliceFrameColor &sipStrings_QtDataVisualization[7016]
#define sipNameNr_setSubSegmentCount 7035
#define sipName_setSubSegmentCount &sipStrings_QtDataVisualization[7035]
#define sipNameNr_setUserDefinedMesh 7054
#define sipName_setUserDefinedMesh &sipStrings_QtDataVisualization[7054]
#define sipNameNr_setXPosRolePattern 7073
#define sipName_setXPosRolePattern &sipStrings_QtDataVisualization[7073]
#define sipNameNr_setXPosRoleReplace 7092
#define sipName_setXPosRoleReplace &sipStrings_QtDataVisualization[7092]
#define sipNameNr_setYPosRolePattern 7111
#define sipName_setYPosRolePattern &sipStrings_QtDataVisualization[7111]
#define sipNameNr_setYPosRoleReplace 7130
#define sipName_setYPosRoleReplace &sipStrings_QtDataVisualization[7130]
#define sipNameNr_setZPosRolePattern 7149
#define sipName_setZPosRolePattern &sipStrings_QtDataVisualization[7149]
#define sipNameNr_setZPosRoleReplace 7168
#define sipName_setZPosRoleReplace &sipStrings_QtDataVisualization[7168]
#define sipNameNr_sliceIndexXChanged 7187
#define sipName_sliceIndexXChanged &sipStrings_QtDataVisualization[7187]
#define sipNameNr_sliceIndexYChanged 7206
#define sipName_sliceIndexYChanged &sipStrings_QtDataVisualization[7206]
#define sipNameNr_sliceIndexZChanged 7225
#define sipName_sliceIndexZChanged &sipStrings_QtDataVisualization[7225]
#define sipNameNr_textureDataChanged 7244
#define sipName_textureDataChanged &sipStrings_QtDataVisualization[7244]
#define sipNameNr_textureFileChanged 7263
#define sipName_textureFileChanged &sipStrings_QtDataVisualization[7263]
#define sipNameNr_useModelCategories 7282
#define sipName_useModelCategories &sipStrings_QtDataVisualization[7282]
#define sipNameNr_windowColorChanged 7301
#define sipName_windowColorChanged &sipStrings_QtDataVisualization[7301]
#define sipNameNr_zoomEnabledChanged 7320
#define sipName_zoomEnabledChanged &sipStrings_QtDataVisualization[7320]
#define sipNameNr_CameraPresetFront 7339
#define sipName_CameraPresetFront &sipStrings_QtDataVisualization[7339]
#define sipNameNr_CameraPresetRight 7357
#define sipName_CameraPresetRight &sipStrings_QtDataVisualization[7357]
#define sipNameNr_ColorStyleUniform 7375
#define sipName_ColorStyleUniform &sipStrings_QtDataVisualization[7375]
#define sipNameNr_ElementAxisXLabel 7393
#define sipName_ElementAxisXLabel &sipStrings_QtDataVisualization[7393]
#define sipNameNr_ElementAxisYLabel 7411
#define sipName_ElementAxisYLabel &sipStrings_QtDataVisualization[7411]
#define sipNameNr_ElementAxisZLabel 7429
#define sipName_ElementAxisZLabel &sipStrings_QtDataVisualization[7429]
#define sipNameNr_ElementCustomItem 7447
#define sipName_ElementCustomItem &sipStrings_QtDataVisualization[7447]
#define sipNameNr_QAbstract3DSeries 7465
#define sipName_QAbstract3DSeries &sipStrings_QtDataVisualization[7465]
#define sipNameNr_QScatterDataProxy 7483
#define sipName_QScatterDataProxy &sipStrings_QtDataVisualization[7483]
#define sipNameNr_QSurfaceDataProxy 7501
#define sipName_QSurfaceDataProxy &sipStrings_QtDataVisualization[7501]
#define sipNameNr_SeriesTypeScatter 7519
#define sipName_SeriesTypeScatter &sipStrings_QtDataVisualization[7519]
#define sipNameNr_SeriesTypeSurface 7537
#define sipName_SeriesTypeSurface &sipStrings_QtDataVisualization[7537]
#define sipNameNr_ShadowQualityHigh 7555
#define sipName_ShadowQualityHigh &sipStrings_QtDataVisualization[7555]
#define sipNameNr_ShadowQualityNone 7573
#define sipName_ShadowQualityNone &sipStrings_QtDataVisualization[7573]
#define sipNameNr_autoRowCategories 7591
#define sipName_autoRowCategories &sipStrings_QtDataVisualization[7591]
#define sipNameNr_autoScaleYChanged 7609
#define sipName_autoScaleYChanged &sipStrings_QtDataVisualization[7609]
#define sipNameNr_barSpacingChanged 7627
#define sipName_barSpacingChanged &sipStrings_QtDataVisualization[7627]
#define sipNameNr_baseColorsChanged 7645
#define sipName_baseColorsChanged &sipStrings_QtDataVisualization[7645]
#define sipNameNr_colorStyleChanged 7663
#define sipName_colorStyleChanged &sipStrings_QtDataVisualization[7663]
#define sipNameNr_colorTableChanged 7681
#define sipName_colorTableChanged &sipStrings_QtDataVisualization[7681]
#define sipNameNr_columnAxisChanged 7699
#define sipName_columnAxisChanged &sipStrings_QtDataVisualization[7699]
#define sipNameNr_columnRoleChanged 7717
#define sipName_columnRoleChanged &sipStrings_QtDataVisualization[7717]
#define sipNameNr_columnRolePattern 7735
#define sipName_columnRolePattern &sipStrings_QtDataVisualization[7735]
#define sipNameNr_columnRoleReplace 7753
#define sipName_columnRoleReplace &sipStrings_QtDataVisualization[7753]
#define sipNameNr_createNewInstance 7771
#define sipName_createNewInstance &sipStrings_QtDataVisualization[7771]
#define sipNameNr_createTextureData 7789
#define sipName_createTextureData &sipStrings_QtDataVisualization[7789]
#define sipNameNr_currentFpsChanged 7807
#define sipName_currentFpsChanged &sipStrings_QtDataVisualization[7807]
#define sipNameNr_drawSlicesChanged 7825
#define sipName_drawSlicesChanged &sipStrings_QtDataVisualization[7825]
#define sipNameNr_floorLevelChanged 7843
#define sipName_floorLevelChanged &sipStrings_QtDataVisualization[7843]
#define sipNameNr_isAutoAdjustRange 7861
#define sipName_isAutoAdjustRange &sipStrings_QtDataVisualization[7861]
#define sipNameNr_isOrthoProjection 7879
#define sipName_isOrthoProjection &sipStrings_QtDataVisualization[7879]
#define sipNameNr_isRotationEnabled 7897
#define sipName_isRotationEnabled &sipStrings_QtDataVisualization[7897]
#define sipNameNr_isScalingAbsolute 7915
#define sipName_isScalingAbsolute &sipStrings_QtDataVisualization[7915]
#define sipNameNr_labelAutoRotation 7933
#define sipName_labelAutoRotation &sipStrings_QtDataVisualization[7933]
#define sipNameNr_lightColorChanged 1160
#define sipName_lightColorChanged &sipStrings_QtDataVisualization[1160]
#define sipNameNr_measureFpsChanged 7951
#define sipName_measureFpsChanged &sipStrings_QtDataVisualization[7951]
#define sipNameNr_meshSmoothChanged 7969
#define sipName_meshSmoothChanged &sipStrings_QtDataVisualization[7969]
#define sipNameNr_mouseReleaseEvent 7987
#define sipName_mouseReleaseEvent &sipStrings_QtDataVisualization[7987]
#define sipNameNr_optimizationHints 8005
#define sipName_optimizationHints &sipStrings_QtDataVisualization[8005]
#define sipNameNr_radialLabelOffset 8023
#define sipName_radialLabelOffset &sipStrings_QtDataVisualization[8023]
#define sipNameNr_reflectionChanged 8041
#define sipName_reflectionChanged &sipStrings_QtDataVisualization[8041]
#define sipNameNr_releaseCustomItem 8059
#define sipName_releaseCustomItem &sipStrings_QtDataVisualization[8059]
#define sipNameNr_removeCustomItems 8077
#define sipName_removeCustomItems &sipStrings_QtDataVisualization[8077]
#define sipNameNr_setAllowNegatives 8095
#define sipName_setAllowNegatives &sipStrings_QtDataVisualization[8095]
#define sipNameNr_setCameraPosition 8113
#define sipName_setCameraPosition &sipStrings_QtDataVisualization[8113]
#define sipNameNr_setLabelTextColor 8131
#define sipName_setLabelTextColor &sipStrings_QtDataVisualization[8131]
#define sipNameNr_setRowRolePattern 8149
#define sipName_setRowRolePattern &sipStrings_QtDataVisualization[8149]
#define sipNameNr_setRowRoleReplace 8167
#define sipName_setRowRoleReplace &sipStrings_QtDataVisualization[8167]
#define sipNameNr_setShowEdgeLabels 8185
#define sipName_setShowEdgeLabels &sipStrings_QtDataVisualization[8185]
#define sipNameNr_setSliceFrameGaps 8203
#define sipName_setSliceFrameGaps &sipStrings_QtDataVisualization[8203]
#define sipNameNr_setSubTextureData 8221
#define sipName_setSubTextureData &sipStrings_QtDataVisualization[8221]
#define sipNameNr_setWireframeColor 8239
#define sipName_setWireframeColor &sipStrings_QtDataVisualization[8239]
#define sipNameNr_titleFixedChanged 8257
#define sipName_titleFixedChanged &sipStrings_QtDataVisualization[8257]
#define sipNameNr_visibilityChanged 8275
#define sipName_visibilityChanged &sipStrings_QtDataVisualization[8275]
#define sipNameNr_AxisOrientationX 8293
#define sipName_AxisOrientationX &sipStrings_QtDataVisualization[8293]
#define sipNameNr_AxisOrientationY 8310
#define sipName_AxisOrientationY &sipStrings_QtDataVisualization[8310]
#define sipNameNr_AxisOrientationZ 8327
#define sipName_AxisOrientationZ &sipStrings_QtDataVisualization[8327]
#define sipNameNr_AxisTypeCategory 8344
#define sipName_AxisTypeCategory &sipStrings_QtDataVisualization[8344]
#define sipNameNr_CameraPresetLeft 8361
#define sipName_CameraPresetLeft &sipStrings_QtDataVisualization[8361]
#define sipNameNr_CameraPresetNone 8378
#define sipName_CameraPresetNone &sipStrings_QtDataVisualization[8378]
#define sipNameNr_OptimizationHint 226
#define sipName_OptimizationHint &sipStrings_QtDataVisualization[226]
#define sipNameNr_QAbstract3DGraph 8395
#define sipName_QAbstract3DGraph &sipStrings_QtDataVisualization[8395]
#define sipNameNr_8412 8412
#define sipName_8412 &sipStrings_QtDataVisualization[8412]
#define sipNameNr_QScatter3DSeries 8429
#define sipName_QScatter3DSeries &sipStrings_QtDataVisualization[8429]
#define sipNameNr_QScatterDataItem 8446
#define sipName_QScatterDataItem &sipStrings_QtDataVisualization[8446]
#define sipNameNr_QSurface3DSeries 8463
#define sipName_QSurface3DSeries &sipStrings_QtDataVisualization[8463]
#define sipNameNr_QSurfaceDataItem 8480
#define sipName_QSurfaceDataItem &sipStrings_QtDataVisualization[8480]
#define sipNameNr_ShadowQualityLow 8497
#define sipName_ShadowQualityLow &sipStrings_QtDataVisualization[8497]
#define sipNameNr_ThemeUserDefined 8514
#define sipName_ThemeUserDefined &sipStrings_QtDataVisualization[8514]
#define sipNameNr_baseColorChanged 8531
#define sipName_baseColorChanged &sipStrings_QtDataVisualization[8531]
#define sipNameNr_columnCategories 8548
#define sipName_columnCategories &sipStrings_QtDataVisualization[8548]
#define sipNameNr_dataProxyChanged 8565
#define sipName_dataProxyChanged &sipStrings_QtDataVisualization[8565]
#define sipNameNr_devicePixelRatio 8582
#define sipName_devicePixelRatio &sipStrings_QtDataVisualization[8582]
#define sipNameNr_disconnectNotify 8599
#define sipName_disconnectNotify &sipStrings_QtDataVisualization[8599]
#define sipNameNr_formatterChanged 8616
#define sipName_formatterChanged &sipStrings_QtDataVisualization[8616]
#define sipNameNr_heightMapChanged 8633
#define sipName_heightMapChanged &sipStrings_QtDataVisualization[8633]
#define sipNameNr_inputViewChanged 8650
#define sipName_inputViewChanged &sipStrings_QtDataVisualization[8650]
#define sipNameNr_itemCountChanged 8667
#define sipName_itemCountChanged &sipStrings_QtDataVisualization[8667]
#define sipNameNr_itemLabelChanged 8684
#define sipName_itemLabelChanged &sipStrings_QtDataVisualization[8684]
#define sipNameNr_itemModelChanged 8701
#define sipName_itemModelChanged &sipStrings_QtDataVisualization[8701]
#define sipNameNr_maxXValueChanged 8718
#define sipName_maxXValueChanged &sipStrings_QtDataVisualization[8718]
#define sipNameNr_maxYValueChanged 8735
#define sipName_maxYValueChanged &sipStrings_QtDataVisualization[8735]
#define sipNameNr_maxZValueChanged 8752
#define sipName_maxZValueChanged &sipStrings_QtDataVisualization[8752]
#define sipNameNr_meshAngleChanged 8769
#define sipName_meshAngleChanged &sipStrings_QtDataVisualization[8769]
#define sipNameNr_minXValueChanged 8786
#define sipName_minXValueChanged &sipStrings_QtDataVisualization[8786]
#define sipNameNr_minYValueChanged 8803
#define sipName_minYValueChanged &sipStrings_QtDataVisualization[8803]
#define sipNameNr_minZValueChanged 8820
#define sipName_minZValueChanged &sipStrings_QtDataVisualization[8820]
#define sipNameNr_previousInputPos 8837
#define sipName_previousInputPos &sipStrings_QtDataVisualization[8837]
#define sipNameNr_removeCustomItem 8854
#define sipName_removeCustomItem &sipStrings_QtDataVisualization[8854]
#define sipNameNr_rowCategoryIndex 8871
#define sipName_rowCategoryIndex &sipStrings_QtDataVisualization[8871]
#define sipNameNr_rowColorsChanged 8888
#define sipName_rowColorsChanged &sipStrings_QtDataVisualization[8888]
#define sipNameNr_rowLabelsChanged 8905
#define sipName_rowLabelsChanged &sipStrings_QtDataVisualization[8905]
#define sipNameNr_setBaseGradients 8922
#define sipName_setBaseGradients &sipStrings_QtDataVisualization[8922]
#define sipNameNr_setBorderEnabled 8939
#define sipName_setBorderEnabled &sipStrings_QtDataVisualization[8939]
#define sipNameNr_setGridLineColor 8956
#define sipName_setGridLineColor &sipStrings_QtDataVisualization[8956]
#define sipNameNr_setHeightMapFile 8973
#define sipName_setHeightMapFile &sipStrings_QtDataVisualization[8973]
#define sipNameNr_setInputPosition 8990
#define sipName_setInputPosition &sipStrings_QtDataVisualization[8990]
#define sipNameNr_setLightStrength 9007
#define sipName_setLightStrength &sipStrings_QtDataVisualization[9007]
#define sipNameNr_setPrimarySeries 9024
#define sipName_setPrimarySeries &sipStrings_QtDataVisualization[9024]
#define sipNameNr_setRowCategories 9041
#define sipName_setRowCategories &sipStrings_QtDataVisualization[9041]
#define sipNameNr_setSelectedPoint 9058
#define sipName_setSelectedPoint &sipStrings_QtDataVisualization[9058]
#define sipNameNr_setSelectionMode 9075
#define sipName_setSelectionMode &sipStrings_QtDataVisualization[9075]
#define sipNameNr_setShadowCasting 9092
#define sipName_setShadowCasting &sipStrings_QtDataVisualization[9092]
#define sipNameNr_setShadowQuality 9109
#define sipName_setShadowQuality &sipStrings_QtDataVisualization[9109]
#define sipNameNr_setSlicingActive 9126
#define sipName_setSlicingActive &sipStrings_QtDataVisualization[9126]
#define sipNameNr_setTextureFormat 9143
#define sipName_setTextureFormat &sipStrings_QtDataVisualization[9143]
#define sipNameNr_setTextureHeight 9160
#define sipName_setTextureHeight &sipStrings_QtDataVisualization[9160]
#define sipNameNr_setWrapXRotation 9177
#define sipName_setWrapXRotation &sipStrings_QtDataVisualization[9177]
#define sipNameNr_setWrapYRotation 9194
#define sipName_setWrapYRotation &sipStrings_QtDataVisualization[9194]
#define sipNameNr_shadowsSupported 9211
#define sipName_shadowsSupported &sipStrings_QtDataVisualization[9211]
#define sipNameNr_sliceFrameWidths 9228
#define sipName_sliceFrameWidths &sipStrings_QtDataVisualization[9228]
#define sipNameNr_subGridPositions 9245
#define sipName_subGridPositions &sipStrings_QtDataVisualization[9245]
#define sipNameNr_textColorChanged 9262
#define sipName_textColorChanged &sipStrings_QtDataVisualization[9262]
#define sipNameNr_textureDataWidth 9279
#define sipName_textureDataWidth &sipStrings_QtDataVisualization[9279]
#define sipNameNr_useHighDefShader 9296
#define sipName_useHighDefShader &sipStrings_QtDataVisualization[9296]
#define sipNameNr_valueAxisChanged 9313
#define sipName_valueAxisChanged &sipStrings_QtDataVisualization[9313]
#define sipNameNr_valueRoleChanged 9330
#define sipName_valueRoleChanged &sipStrings_QtDataVisualization[9330]
#define sipNameNr_valueRolePattern 9347
#define sipName_valueRolePattern &sipStrings_QtDataVisualization[9347]
#define sipNameNr_valueRoleReplace 9364
#define sipName_valueRoleReplace &sipStrings_QtDataVisualization[9364]
#define sipNameNr_xRotationChanged 9381
#define sipName_xRotationChanged &sipStrings_QtDataVisualization[9381]
#define sipNameNr_yRotationChanged 9398
#define sipName_yRotationChanged &sipStrings_QtDataVisualization[9398]
#define sipNameNr_zoomLevelChanged 9415
#define sipName_zoomLevelChanged &sipStrings_QtDataVisualization[9415]
#define sipNameNr_AxisOrientation 330
#define sipName_AxisOrientation &sipStrings_QtDataVisualization[330]
#define sipNameNr_DataTypeScatter 9432
#define sipName_DataTypeScatter &sipStrings_QtDataVisualization[9432]
#define sipNameNr_DataTypeSurface 9448
#define sipName_DataTypeSurface &sipStrings_QtDataVisualization[9448]
#define sipNameNr_MeshUserDefined 9464
#define sipName_MeshUserDefined &sipStrings_QtDataVisualization[9464]
#define sipNameNr_Q3DInputHandler 9480
#define sipName_Q3DInputHandler &sipStrings_QtDataVisualization[9480]
#define sipNameNr_Q3DTheme__Theme 9496
#define sipName_Q3DTheme__Theme &sipStrings_QtDataVisualization[9496]
#define sipNameNr_QAbstract3DAxis 9512
#define sipName_QAbstract3DAxis &sipStrings_QtDataVisualization[9512]
#define sipNameNr_QCategory3DAxis 9528
#define sipName_QCategory3DAxis &sipStrings_QtDataVisualization[9528]
#define sipNameNr_QCustom3DVolume 9544
#define sipName_QCustom3DVolume &sipStrings_QtDataVisualization[9544]
#define sipNameNr_SelectionColumn 9560
#define sipName_SelectionColumn &sipStrings_QtDataVisualization[9560]
#define sipNameNr_addInputHandler 9576
#define sipName_addInputHandler &sipStrings_QtDataVisualization[9576]
#define sipNameNr_alphaMultiplier 9592
#define sipName_alphaMultiplier &sipStrings_QtDataVisualization[9592]
#define sipNameNr_backgroundColor 9608
#define sipName_backgroundColor &sipStrings_QtDataVisualization[9608]
#define sipNameNr_barSeriesMargin 9624
#define sipName_barSeriesMargin &sipStrings_QtDataVisualization[9624]
#define sipNameNr_drawModeChanged 9640
#define sipName_drawModeChanged &sipStrings_QtDataVisualization[9640]
#define sipNameNr_drawSliceFrames 9656
#define sipName_drawSliceFrames &sipStrings_QtDataVisualization[9656]
#define sipNameNr_isBorderEnabled 9672
#define sipName_isBorderEnabled &sipStrings_QtDataVisualization[9672]
#define sipNameNr_isShadowCasting 9688
#define sipName_isShadowCasting &sipStrings_QtDataVisualization[9688]
#define sipNameNr_isSlicingActive 9704
#define sipName_isSlicingActive &sipStrings_QtDataVisualization[9704]
#define sipNameNr_itemLabelFormat 9720
#define sipName_itemLabelFormat &sipStrings_QtDataVisualization[9720]
#define sipNameNr_itemSizeChanged 9736
#define sipName_itemSizeChanged &sipStrings_QtDataVisualization[9736]
#define sipNameNr_keyReleaseEvent 9752
#define sipName_keyReleaseEvent &sipStrings_QtDataVisualization[9752]
#define sipNameNr_meshFileChanged 9768
#define sipName_meshFileChanged &sipStrings_QtDataVisualization[9768]
#define sipNameNr_mousePressEvent 9784
#define sipName_mousePressEvent &sipStrings_QtDataVisualization[9784]
#define sipNameNr_positionChanged 9800
#define sipName_positionChanged &sipStrings_QtDataVisualization[9800]
#define sipNameNr_preserveOpacity 9816
#define sipName_preserveOpacity &sipStrings_QtDataVisualization[9816]
#define sipNameNr_reversedChanged 9832
#define sipName_reversedChanged &sipStrings_QtDataVisualization[9832]
#define sipNameNr_rotationChanged 9848
#define sipName_rotationChanged &sipStrings_QtDataVisualization[9848]
#define sipNameNr_rowCountChanged 9864
#define sipName_rowCountChanged &sipStrings_QtDataVisualization[9864]
#define sipNameNr_selectedElement 9880
#define sipName_selectedElement &sipStrings_QtDataVisualization[9880]
#define sipNameNr_setActiveCamera 9896
#define sipName_setActiveCamera &sipStrings_QtDataVisualization[9896]
#define sipNameNr_setAutoPosition 9912
#define sipName_setAutoPosition &sipStrings_QtDataVisualization[9912]
#define sipNameNr_setBarThickness 9928
#define sipName_setBarThickness &sipStrings_QtDataVisualization[9928]
#define sipNameNr_setBaseGradient 9944
#define sipName_setBaseGradient &sipStrings_QtDataVisualization[9944]
#define sipNameNr_setCameraPreset 9960
#define sipName_setCameraPreset &sipStrings_QtDataVisualization[9960]
#define sipNameNr_setColumnLabels 9976
#define sipName_setColumnLabels &sipStrings_QtDataVisualization[9976]
#define sipNameNr_setFacingCamera 9992
#define sipName_setFacingCamera &sipStrings_QtDataVisualization[9992]
#define sipNameNr_setMaxZoomLevel 10008
#define sipName_setMaxZoomLevel &sipStrings_QtDataVisualization[10008]
#define sipNameNr_setMeshRotation 10024
#define sipName_setMeshRotation &sipStrings_QtDataVisualization[10024]
#define sipNameNr_setMinZoomLevel 10040
#define sipName_setMinZoomLevel &sipStrings_QtDataVisualization[10040]
#define sipNameNr_setPrevDistance 10056
#define sipName_setPrevDistance &sipStrings_QtDataVisualization[10056]
#define sipNameNr_setReflectivity 10072
#define sipName_setReflectivity &sipStrings_QtDataVisualization[10072]
#define sipNameNr_setRotationRole 10088
#define sipName_setRotationRole &sipStrings_QtDataVisualization[10088]
#define sipNameNr_setSegmentCount 10104
#define sipName_setSegmentCount &sipStrings_QtDataVisualization[10104]
#define sipNameNr_setSelectedItem 10120
#define sipName_setSelectedItem &sipStrings_QtDataVisualization[10120]
#define sipNameNr_setSliceIndices 10136
#define sipName_setSliceIndices &sipStrings_QtDataVisualization[10136]
#define sipNameNr_setTextureDepth 10152
#define sipName_setTextureDepth &sipStrings_QtDataVisualization[10152]
#define sipNameNr_setTextureImage 10168
#define sipName_setTextureImage &sipStrings_QtDataVisualization[10168]
#define sipNameNr_setTextureWidth 10184
#define sipName_setTextureWidth &sipStrings_QtDataVisualization[10184]
#define sipNameNr_setTitleVisible 10200
#define sipName_setTitleVisible &sipStrings_QtDataVisualization[10200]
#define sipNameNr_sliceFrameColor 10216
#define sipName_sliceFrameColor &sipStrings_QtDataVisualization[10216]
#define sipNameNr_subSegmentCount 10232
#define sipName_subSegmentCount &sipStrings_QtDataVisualization[10232]
#define sipNameNr_userDefinedMesh 10248
#define sipName_userDefinedMesh &sipStrings_QtDataVisualization[10248]
#define sipNameNr_viewportChanged 10264
#define sipName_viewportChanged &sipStrings_QtDataVisualization[10264]
#define sipNameNr_xPosRoleChanged 10280
#define sipName_xPosRoleChanged &sipStrings_QtDataVisualization[10280]
#define sipNameNr_xPosRolePattern 10296
#define sipName_xPosRolePattern &sipStrings_QtDataVisualization[10296]
#define sipNameNr_xPosRoleReplace 10312
#define sipName_xPosRoleReplace &sipStrings_QtDataVisualization[10312]
#define sipNameNr_yPosRoleChanged 10328
#define sipName_yPosRoleChanged &sipStrings_QtDataVisualization[10328]
#define sipNameNr_yPosRolePattern 10344
#define sipName_yPosRolePattern &sipStrings_QtDataVisualization[10344]
#define sipNameNr_yPosRoleReplace 10360
#define sipName_yPosRoleReplace &sipStrings_QtDataVisualization[10360]
#define sipNameNr_zPosRoleChanged 10376
#define sipName_zPosRoleChanged &sipStrings_QtDataVisualization[10376]
#define sipNameNr_zPosRolePattern 10392
#define sipName_zPosRolePattern &sipStrings_QtDataVisualization[10392]
#define sipNameNr_zPosRoleReplace 10408
#define sipName_zPosRoleReplace &sipStrings_QtDataVisualization[10408]
#define sipNameNr_MMBCumulativeY 10424
#define sipName_MMBCumulativeY &sipStrings_QtDataVisualization[10424]
#define sipNameNr_QCustom3DLabel 10439
#define sipName_QCustom3DLabel &sipStrings_QtDataVisualization[10439]
#define sipNameNr_10454 10454
#define sipName_10454 &sipStrings_QtDataVisualization[10454]
#define sipNameNr_SelectionSlice 10469
#define sipName_SelectionSlice &sipStrings_QtDataVisualization[10469]
#define sipNameNr_SeriesTypeNone 10484
#define sipName_SeriesTypeNone &sipStrings_QtDataVisualization[10484]
#define sipNameNr_ThemeStoneMoss 10499
#define sipName_ThemeStoneMoss &sipStrings_QtDataVisualization[10499]
#define sipNameNr_allowNegatives 10514
#define sipName_allowNegatives &sipStrings_QtDataVisualization[10514]
#define sipNameNr_clearSelection 10529
#define sipName_clearSelection &sipStrings_QtDataVisualization[10529]
#define sipNameNr_copyValuesFrom 10544
#define sipName_copyValuesFrom &sipStrings_QtDataVisualization[10544]
#define sipNameNr_isAutoPosition 10559
#define sipName_isAutoPosition &sipStrings_QtDataVisualization[10559]
#define sipNameNr_isFacingCamera 10574
#define sipName_isFacingCamera &sipStrings_QtDataVisualization[10574]
#define sipNameNr_isTitleVisible 10589
#define sipName_isTitleVisible &sipStrings_QtDataVisualization[10589]
#define sipNameNr_labelPositions 10604
#define sipName_labelPositions &sipStrings_QtDataVisualization[10604]
#define sipNameNr_labelTextColor 10619
#define sipName_labelTextColor &sipStrings_QtDataVisualization[10619]
#define sipNameNr_mouseMoveEvent 10634
#define sipName_mouseMoveEvent &sipStrings_QtDataVisualization[10634]
#define sipNameNr_rowAxisChanged 10649
#define sipName_rowAxisChanged &sipStrings_QtDataVisualization[10649]
#define sipNameNr_rowRoleChanged 10664
#define sipName_rowRoleChanged &sipStrings_QtDataVisualization[10664]
#define sipNameNr_rowRolePattern 10679
#define sipName_rowRolePattern &sipStrings_QtDataVisualization[10679]
#define sipNameNr_rowRoleReplace 10694
#define sipName_rowRoleReplace &sipStrings_QtDataVisualization[10694]
#define sipNameNr_scalingChanged 10709
#define sipName_scalingChanged &sipStrings_QtDataVisualization[10709]
#define sipNameNr_selectedSeries 10724
#define sipName_selectedSeries &sipStrings_QtDataVisualization[10724]
#define sipNameNr_setActiveLight 10739
#define sipName_setActiveLight &sipStrings_QtDataVisualization[10739]
#define sipNameNr_setActiveTheme 10754
#define sipName_setActiveTheme &sipStrings_QtDataVisualization[10754]
#define sipNameNr_setAspectRatio 10769
#define sipName_setAspectRatio &sipStrings_QtDataVisualization[10769]
#define sipNameNr_setAutoSubGrid 10784
#define sipName_setAutoSubGrid &sipStrings_QtDataVisualization[10784]
#define sipNameNr_setGridEnabled 10799
#define sipName_setGridEnabled &sipStrings_QtDataVisualization[10799]
#define sipNameNr_setLabelFormat 10814
#define sipName_setLabelFormat &sipStrings_QtDataVisualization[10814]
#define sipNameNr_setSelectedBar 10829
#define sipName_setSelectedBar &sipStrings_QtDataVisualization[10829]
#define sipNameNr_setSliceIndexX 10844
#define sipName_setSliceIndexX &sipStrings_QtDataVisualization[10844]
#define sipNameNr_setSliceIndexY 10859
#define sipName_setSliceIndexY &sipStrings_QtDataVisualization[10859]
#define sipNameNr_setSliceIndexZ 10874
#define sipName_setSliceIndexZ &sipStrings_QtDataVisualization[10874]
#define sipNameNr_setTextureData 10889
#define sipName_setTextureData &sipStrings_QtDataVisualization[10889]
#define sipNameNr_setTextureFile 10904
#define sipName_setTextureFile &sipStrings_QtDataVisualization[10904]
#define sipNameNr_setValueRanges 10919
#define sipName_setValueRanges &sipStrings_QtDataVisualization[10919]
#define sipNameNr_setWindowColor 10934
#define sipName_setWindowColor &sipStrings_QtDataVisualization[10934]
#define sipNameNr_setZoomEnabled 10949
#define sipName_setZoomEnabled &sipStrings_QtDataVisualization[10949]
#define sipNameNr_showEdgeLabels 10964
#define sipName_showEdgeLabels &sipStrings_QtDataVisualization[10964]
#define sipNameNr_sliceFrameGaps 10979
#define sipName_sliceFrameGaps &sipStrings_QtDataVisualization[10979]
#define sipNameNr_stringForValue 10994
#define sipName_stringForValue &sipStrings_QtDataVisualization[10994]
#define sipNameNr_textureChanged 11009
#define sipName_textureChanged &sipStrings_QtDataVisualization[11009]
#define sipNameNr_visibleChanged 11024
#define sipName_visibleChanged &sipStrings_QtDataVisualization[11024]
#define sipNameNr_wireframeColor 11039
#define sipName_wireframeColor &sipStrings_QtDataVisualization[11039]
#define sipNameNr_AxisTypeValue 11054
#define sipName_AxisTypeValue &sipStrings_QtDataVisualization[11054]
#define sipNameNr_DrawWireframe 11068
#define sipName_DrawWireframe &sipStrings_QtDataVisualization[11068]
#define sipNameNr_ElementSeries 11082
#define sipName_ElementSeries &sipStrings_QtDataVisualization[11082]
#define sipNameNr_InputViewNone 11096
#define sipName_InputViewNone &sipStrings_QtDataVisualization[11096]
#define sipNameNr_MMBCumulative 11110
#define sipName_MMBCumulative &sipStrings_QtDataVisualization[11110]
#define sipNameNr_MeshBevelCube 11124
#define sipName_MeshBevelCube &sipStrings_QtDataVisualization[11124]
#define sipNameNr_QBarDataProxy 11138
#define sipName_QBarDataProxy &sipStrings_QtDataVisualization[11138]
#define sipNameNr_QCustom3DItem 11152
#define sipName_QCustom3DItem &sipStrings_QtDataVisualization[11152]
#define sipNameNr_11166 11166
#define sipName_11166 &sipStrings_QtDataVisualization[11166]
#define sipNameNr_SelectionFlag 364
#define sipName_SelectionFlag &sipStrings_QtDataVisualization[364]
#define sipNameNr_SelectionItem 11180
#define sipName_SelectionItem &sipStrings_QtDataVisualization[11180]
#define sipNameNr_SelectionNone 11194
#define sipName_SelectionNone &sipStrings_QtDataVisualization[11194]
#define sipNameNr_SeriesTypeBar 11208
#define sipName_SeriesTypeBar &sipStrings_QtDataVisualization[11208]
#define sipNameNr_ShadowQuality 396
#define sipName_ShadowQuality &sipStrings_QtDataVisualization[396]
#define sipNameNr_ThemeArmyBlue 11222
#define sipName_ThemeArmyBlue &sipStrings_QtDataVisualization[11222]
#define sipNameNr_ThemeIsabelle 11236
#define sipName_ThemeIsabelle &sipStrings_QtDataVisualization[11236]
#define sipNameNr_addCustomItem 11250
#define sipName_addCustomItem &sipStrings_QtDataVisualization[11250]
#define sipNameNr_baseGradients 11264
#define sipName_baseGradients &sipStrings_QtDataVisualization[11264]
#define sipNameNr_connectNotify 8602
#define sipName_connectNotify &sipStrings_QtDataVisualization[8602]
#define sipNameNr_focusOutEvent 11278
#define sipName_focusOutEvent &sipStrings_QtDataVisualization[11278]
#define sipNameNr_gridLineColor 11292
#define sipName_gridLineColor &sipStrings_QtDataVisualization[11292]
#define sipNameNr_gridPositions 11306
#define sipName_gridPositions &sipStrings_QtDataVisualization[11306]
#define sipNameNr_heightMapFile 11320
#define sipName_heightMapFile &sipStrings_QtDataVisualization[11320]
#define sipNameNr_inputHandlers 11334
#define sipName_inputHandlers &sipStrings_QtDataVisualization[11334]
#define sipNameNr_inputPosition 11348
#define sipName_inputPosition &sipStrings_QtDataVisualization[11348]
#define sipNameNr_isGridEnabled 11362
#define sipName_isGridEnabled &sipStrings_QtDataVisualization[11362]
#define sipNameNr_isZoomEnabled 11376
#define sipName_isZoomEnabled &sipStrings_QtDataVisualization[11376]
#define sipNameNr_itemsInserted 11390
#define sipName_itemsInserted &sipStrings_QtDataVisualization[11390]
#define sipNameNr_keyPressEvent 11404
#define sipName_keyPressEvent &sipStrings_QtDataVisualization[11404]
#define sipNameNr_labelsChanged 11418
#define sipName_labelsChanged &sipStrings_QtDataVisualization[11418]
#define sipNameNr_lightStrength 11432
#define sipName_lightStrength &sipStrings_QtDataVisualization[11432]
#define sipNameNr_localeChanged 11446
#define sipName_localeChanged &sipStrings_QtDataVisualization[11446]
#define sipNameNr_marginChanged 11460
#define sipName_marginChanged &sipStrings_QtDataVisualization[11460]
#define sipNameNr_primarySeries 11474
#define sipName_primarySeries &sipStrings_QtDataVisualization[11474]
#define sipNameNr_renderToImage 11488
#define sipName_renderToImage &sipStrings_QtDataVisualization[11488]
#define sipNameNr_rowCategories 11502
#define sipName_rowCategories &sipStrings_QtDataVisualization[11502]
#define sipNameNr_selectedPoint 11516
#define sipName_selectedPoint &sipStrings_QtDataVisualization[11516]
#define sipNameNr_selectionMode 11530
#define sipName_selectionMode &sipStrings_QtDataVisualization[11530]
#define sipNameNr_seriesChanged 11544
#define sipName_seriesChanged &sipStrings_QtDataVisualization[11544]
#define sipNameNr_setAutoScaleY 11558
#define sipName_setAutoScaleY &sipStrings_QtDataVisualization[11558]
#define sipNameNr_setBarSpacing 11572
#define sipName_setBarSpacing &sipStrings_QtDataVisualization[11572]
#define sipNameNr_setBaseColors 11586
#define sipName_setBaseColors &sipStrings_QtDataVisualization[11586]
#define sipNameNr_setColorStyle 11600
#define sipName_setColorStyle &sipStrings_QtDataVisualization[11600]
#define sipNameNr_setColorTable 11614
#define sipName_setColorTable &sipStrings_QtDataVisualization[11614]
#define sipNameNr_setColumnAxis 11628
#define sipName_setColumnAxis &sipStrings_QtDataVisualization[11628]
#define sipNameNr_setColumnRole 11642
#define sipName_setColumnRole &sipStrings_QtDataVisualization[11642]
#define sipNameNr_setDrawSlices 11656
#define sipName_setDrawSlices &sipStrings_QtDataVisualization[11656]
#define sipNameNr_setFloorLevel 11670
#define sipName_setFloorLevel &sipStrings_QtDataVisualization[11670]
#define sipNameNr_setLightColor 11684
#define sipName_setLightColor &sipStrings_QtDataVisualization[11684]
#define sipNameNr_setMeasureFps 11698
#define sipName_setMeasureFps &sipStrings_QtDataVisualization[11698]
#define sipNameNr_setMeshSmooth 11712
#define sipName_setMeshSmooth &sipStrings_QtDataVisualization[11712]
#define sipNameNr_setReflection 11726
#define sipName_setReflection &sipStrings_QtDataVisualization[11726]
#define sipNameNr_setTitleFixed 11740
#define sipName_setTitleFixed &sipStrings_QtDataVisualization[11740]
#define sipNameNr_shadowQuality 11754
#define sipName_shadowQuality &sipStrings_QtDataVisualization[11754]
#define sipNameNr_targetChanged 11768
#define sipName_targetChanged &sipStrings_QtDataVisualization[11768]
#define sipNameNr_textureFormat 11782
#define sipName_textureFormat &sipStrings_QtDataVisualization[11782]
#define sipNameNr_textureHeight 11796
#define sipName_textureHeight &sipStrings_QtDataVisualization[11796]
#define sipNameNr_wrapXRotation 11810
#define sipName_wrapXRotation &sipStrings_QtDataVisualization[11810]
#define sipNameNr_wrapYRotation 11824
#define sipName_wrapYRotation &sipStrings_QtDataVisualization[11824]
#define sipNameNr_AxisTypeNone 11838
#define sipName_AxisTypeNone &sipStrings_QtDataVisualization[11838]
#define sipNameNr_CameraPreset 2528
#define sipName_CameraPreset &sipStrings_QtDataVisualization[2528]
#define sipNameNr_DataTypeNone 11851
#define sipName_DataTypeNone &sipStrings_QtDataVisualization[11851]
#define sipNameNr_MeshBevelBar 11864
#define sipName_MeshBevelBar &sipStrings_QtDataVisualization[11864]
#define sipNameNr_MeshCylinder 11877
#define sipName_MeshCylinder &sipStrings_QtDataVisualization[11877]
#define sipNameNr_QBar3DSeries 11890
#define sipName_QBar3DSeries &sipStrings_QtDataVisualization[11890]
#define sipNameNr_QBarDataItem 11903
#define sipName_QBarDataItem &sipStrings_QtDataVisualization[11903]
#define sipNameNr_QValue3DAxis 11916
#define sipName_QValue3DAxis &sipStrings_QtDataVisualization[11916]
#define sipNameNr_SelectionRow 11929
#define sipName_SelectionRow &sipStrings_QtDataVisualization[11929]
#define sipNameNr_activeCamera 11942
#define sipName_activeCamera &sipStrings_QtDataVisualization[11942]
#define sipNameNr_axisXChanged 11955
#define sipName_axisXChanged &sipStrings_QtDataVisualization[11955]
#define sipNameNr_axisYChanged 11968
#define sipName_axisYChanged &sipStrings_QtDataVisualization[11968]
#define sipNameNr_axisZChanged 11981
#define sipName_axisZChanged &sipStrings_QtDataVisualization[11981]
#define sipNameNr_barThickness 11994
#define sipName_barThickness &sipStrings_QtDataVisualization[11994]
#define sipNameNr_baseGradient 12007
#define sipName_baseGradient &sipStrings_QtDataVisualization[12007]
#define sipNameNr_cameraPreset 12020
#define sipName_cameraPreset &sipStrings_QtDataVisualization[12020]
#define sipNameNr_columnLabels 12033
#define sipName_columnLabels &sipStrings_QtDataVisualization[12033]
#define sipNameNr_focusInEvent 12046
#define sipName_focusInEvent &sipStrings_QtDataVisualization[12046]
#define sipNameNr_insertSeries 12059
#define sipName_insertSeries &sipStrings_QtDataVisualization[12059]
#define sipNameNr_isMeshSmooth 12072
#define sipName_isMeshSmooth &sipStrings_QtDataVisualization[12072]
#define sipNameNr_isReflection 12085
#define sipName_isReflection &sipStrings_QtDataVisualization[12085]
#define sipNameNr_isTitleFixed 12098
#define sipName_isTitleFixed &sipStrings_QtDataVisualization[12098]
#define sipNameNr_itemsChanged 12111
#define sipName_itemsChanged &sipStrings_QtDataVisualization[12111]
#define sipNameNr_itemsRemoved 12124
#define sipName_itemsRemoved &sipStrings_QtDataVisualization[12124]
#define sipNameNr_labelStrings 12137
#define sipName_labelStrings &sipStrings_QtDataVisualization[12137]
#define sipNameNr_labelsChange 12150
#define sipName_labelsChange &sipStrings_QtDataVisualization[12150]
#define sipNameNr_maxZoomLevel 12163
#define sipName_maxZoomLevel &sipStrings_QtDataVisualization[12163]
#define sipNameNr_meshRotation 12176
#define sipName_meshRotation &sipStrings_QtDataVisualization[12176]
#define sipNameNr_minZoomLevel 12189
#define sipName_minZoomLevel &sipStrings_QtDataVisualization[12189]
#define sipNameNr_polarChanged 12202
#define sipName_polarChanged &sipStrings_QtDataVisualization[12202]
#define sipNameNr_populateCopy 12215
#define sipName_populateCopy &sipStrings_QtDataVisualization[12215]
#define sipNameNr_prevDistance 12228
#define sipName_prevDistance &sipStrings_QtDataVisualization[12228]
#define sipNameNr_rangeChanged 12241
#define sipName_rangeChanged &sipStrings_QtDataVisualization[12241]
#define sipNameNr_reflectivity 12254
#define sipName_reflectivity &sipStrings_QtDataVisualization[12254]
#define sipNameNr_releaseTheme 12267
#define sipName_releaseTheme &sipStrings_QtDataVisualization[12267]
#define sipNameNr_removeLabels 12280
#define sipName_removeLabels &sipStrings_QtDataVisualization[12280]
#define sipNameNr_removeSeries 12293
#define sipName_removeSeries &sipStrings_QtDataVisualization[12293]
#define sipNameNr_rotationRole 12306
#define sipName_rotationRole &sipStrings_QtDataVisualization[12306]
#define sipNameNr_rowsInserted 12319
#define sipName_rowsInserted &sipStrings_QtDataVisualization[12319]
#define sipNameNr_sceneChanged 12332
#define sipName_sceneChanged &sipStrings_QtDataVisualization[12332]
#define sipNameNr_segmentCount 12345
#define sipName_segmentCount &sipStrings_QtDataVisualization[12345]
#define sipNameNr_selectedAxis 12358
#define sipName_selectedAxis &sipStrings_QtDataVisualization[12358]
#define sipNameNr_selectedItem 12371
#define sipName_selectedItem &sipStrings_QtDataVisualization[12371]
#define sipNameNr_setAllowZero 12384
#define sipName_setAllowZero &sipStrings_QtDataVisualization[12384]
#define sipNameNr_setBaseColor 12397
#define sipName_setBaseColor &sipStrings_QtDataVisualization[12397]
#define sipNameNr_setDataProxy 12410
#define sipName_setDataProxy &sipStrings_QtDataVisualization[12410]
#define sipNameNr_setFormatter 12423
#define sipName_setFormatter &sipStrings_QtDataVisualization[12423]
#define sipNameNr_setHeightMap 12436
#define sipName_setHeightMap &sipStrings_QtDataVisualization[12436]
#define sipNameNr_setInputView 12449
#define sipName_setInputView &sipStrings_QtDataVisualization[12449]
#define sipNameNr_setItemModel 12462
#define sipName_setItemModel &sipStrings_QtDataVisualization[12462]
#define sipNameNr_setMaxXValue 12475
#define sipName_setMaxXValue &sipStrings_QtDataVisualization[12475]
#define sipNameNr_setMaxYValue 12488
#define sipName_setMaxYValue &sipStrings_QtDataVisualization[12488]
#define sipNameNr_setMaxZValue 12501
#define sipName_setMaxZValue &sipStrings_QtDataVisualization[12501]
#define sipNameNr_setMeshAngle 12514
#define sipName_setMeshAngle &sipStrings_QtDataVisualization[12514]
#define sipNameNr_setMinXValue 12527
#define sipName_setMinXValue &sipStrings_QtDataVisualization[12527]
#define sipNameNr_setMinYValue 12540
#define sipName_setMinYValue &sipStrings_QtDataVisualization[12540]
#define sipNameNr_setMinZValue 12553
#define sipName_setMinZValue &sipStrings_QtDataVisualization[12553]
#define sipNameNr_setRowColors 12566
#define sipName_setRowColors &sipStrings_QtDataVisualization[12566]
#define sipNameNr_setRowLabels 12579
#define sipName_setRowLabels &sipStrings_QtDataVisualization[12579]
#define sipNameNr_setTextColor 12592
#define sipName_setTextColor &sipStrings_QtDataVisualization[12592]
#define sipNameNr_setValueAxis 12605
#define sipName_setValueAxis &sipStrings_QtDataVisualization[12605]
#define sipNameNr_setValueRole 12618
#define sipName_setValueRole &sipStrings_QtDataVisualization[12618]
#define sipNameNr_setXRotation 12631
#define sipName_setXRotation &sipStrings_QtDataVisualization[12631]
#define sipNameNr_setYRotation 12644
#define sipName_setYRotation &sipStrings_QtDataVisualization[12644]
#define sipNameNr_setZoomLevel 12657
#define sipName_setZoomLevel &sipStrings_QtDataVisualization[12657]
#define sipNameNr_textureDepth 12670
#define sipName_textureDepth &sipStrings_QtDataVisualization[12670]
#define sipNameNr_textureWidth 12683
#define sipName_textureWidth &sipStrings_QtDataVisualization[12683]
#define sipNameNr_titleChanged 12696
#define sipName_titleChanged &sipStrings_QtDataVisualization[12696]
#define sipNameNr_DataTypeBar 12709
#define sipName_DataTypeBar &sipStrings_QtDataVisualization[12709]
#define sipNameNr_DrawSurface 12721
#define sipName_DrawSurface &sipStrings_QtDataVisualization[12721]
#define sipNameNr_ElementNone 12733
#define sipName_ElementNone &sipStrings_QtDataVisualization[12733]
#define sipNameNr_ElementType 676
#define sipName_ElementType &sipStrings_QtDataVisualization[676]
#define sipNameNr_MeshMinimal 12745
#define sipName_MeshMinimal &sipStrings_QtDataVisualization[12745]
#define sipNameNr_MeshPyramid 12757
#define sipName_MeshPyramid &sipStrings_QtDataVisualization[12757]
#define sipNameNr_activeLight 12769
#define sipName_activeLight &sipStrings_QtDataVisualization[12769]
#define sipNameNr_activeTheme 12781
#define sipName_activeTheme &sipStrings_QtDataVisualization[12781]
#define sipNameNr_aspectRatio 12793
#define sipName_aspectRatio &sipStrings_QtDataVisualization[12793]
#define sipNameNr_autoSubGrid 12805
#define sipName_autoSubGrid &sipStrings_QtDataVisualization[12805]
#define sipNameNr_baseChanged 12817
#define sipName_baseChanged &sipStrings_QtDataVisualization[12817]
#define sipNameNr_columnCount 12829
#define sipName_columnCount &sipStrings_QtDataVisualization[12829]
#define sipNameNr_customEvent 12841
#define sipName_customEvent &sipStrings_QtDataVisualization[12841]
#define sipNameNr_customItems 12853
#define sipName_customItems &sipStrings_QtDataVisualization[12853]
#define sipNameNr_eventFilter 12865
#define sipName_eventFilter &sipStrings_QtDataVisualization[12865]
#define sipNameNr_exposeEvent 12877
#define sipName_exposeEvent &sipStrings_QtDataVisualization[12877]
#define sipNameNr_focusObject 12889
#define sipName_focusObject &sipStrings_QtDataVisualization[12889]
#define sipNameNr_fontChanged 12901
#define sipName_fontChanged &sipStrings_QtDataVisualization[12901]
#define sipNameNr_insertItems 12913
#define sipName_insertItems &sipStrings_QtDataVisualization[12913]
#define sipNameNr_itemChanged 12925
#define sipName_itemChanged &sipStrings_QtDataVisualization[12925]
#define sipNameNr_labelFormat 12937
#define sipName_labelFormat &sipStrings_QtDataVisualization[12937]
#define sipNameNr_meshChanged 12949
#define sipName_meshChanged &sipStrings_QtDataVisualization[12949]
#define sipNameNr_msaaSamples 12961
#define sipName_msaaSamples &sipStrings_QtDataVisualization[12961]
#define sipNameNr_nameChanged 12973
#define sipName_nameChanged &sipStrings_QtDataVisualization[12973]
#define sipNameNr_nativeEvent 12985
#define sipName_nativeEvent &sipStrings_QtDataVisualization[12985]
#define sipNameNr_orientation 12997
#define sipName_orientation &sipStrings_QtDataVisualization[12997]
#define sipNameNr_parentScene 13009
#define sipName_parentScene &sipStrings_QtDataVisualization[13009]
#define sipNameNr_recalculate 13021
#define sipName_recalculate &sipStrings_QtDataVisualization[13021]
#define sipNameNr_releaseAxis 13033
#define sipName_releaseAxis &sipStrings_QtDataVisualization[13033]
#define sipNameNr_removeItems 13045
#define sipName_removeItems &sipStrings_QtDataVisualization[13045]
#define sipNameNr_renderSlice 13057
#define sipName_renderSlice &sipStrings_QtDataVisualization[13057]
#define sipNameNr_resizeEvent 13069
#define sipName_resizeEvent &sipStrings_QtDataVisualization[13069]
#define sipNameNr_rowsChanged 13081
#define sipName_rowsChanged &sipStrings_QtDataVisualization[13081]
#define sipNameNr_rowsRemoved 13093
#define sipName_rowsRemoved &sipStrings_QtDataVisualization[13093]
#define sipNameNr_selectedBar 13105
#define sipName_selectedBar &sipStrings_QtDataVisualization[13105]
#define sipNameNr_setDrawMode 13117
#define sipName_setDrawMode &sipStrings_QtDataVisualization[13117]
#define sipNameNr_setItemSize 13129
#define sipName_setItemSize &sipStrings_QtDataVisualization[13129]
#define sipNameNr_setMeshFile 13141
#define sipName_setMeshFile &sipStrings_QtDataVisualization[13141]
#define sipNameNr_setPosition 13153
#define sipName_setPosition &sipStrings_QtDataVisualization[13153]
#define sipNameNr_setReversed 13165
#define sipName_setReversed &sipStrings_QtDataVisualization[13165]
#define sipNameNr_setRotation 13177
#define sipName_setRotation &sipStrings_QtDataVisualization[13177]
#define sipNameNr_setXPosRole 13189
#define sipName_setXPosRole &sipStrings_QtDataVisualization[13189]
#define sipNameNr_setYPosRole 13201
#define sipName_setYPosRole &sipStrings_QtDataVisualization[13201]
#define sipNameNr_setZPosRole 13213
#define sipName_setZPosRole &sipStrings_QtDataVisualization[13213]
#define sipNameNr_sliceIndexX 13225
#define sipName_sliceIndexX &sipStrings_QtDataVisualization[13225]
#define sipNameNr_sliceIndexY 13237
#define sipName_sliceIndexY &sipStrings_QtDataVisualization[13237]
#define sipNameNr_sliceIndexZ 13249
#define sipName_sliceIndexZ &sipStrings_QtDataVisualization[13249]
#define sipNameNr_surfaceType 13261
#define sipName_surfaceType &sipStrings_QtDataVisualization[13261]
#define sipNameNr_tabletEvent 13273
#define sipName_tabletEvent &sipStrings_QtDataVisualization[13273]
#define sipNameNr_textChanged 13285
#define sipName_textChanged &sipStrings_QtDataVisualization[13285]
#define sipNameNr_textureData 13297
#define sipName_textureData &sipStrings_QtDataVisualization[13297]
#define sipNameNr_textureFile 13309
#define sipName_textureFile &sipStrings_QtDataVisualization[13309]
#define sipNameNr_typeChanged 13321
#define sipName_typeChanged &sipStrings_QtDataVisualization[13321]
#define sipNameNr_windowColor 13333
#define sipName_windowColor &sipStrings_QtDataVisualization[13333]
#define sipNameNr_ColorStyle 4720
#define sipName_ColorStyle &sipStrings_QtDataVisualization[4720]
#define sipNameNr_MMBAverage 13345
#define sipName_MMBAverage &sipStrings_QtDataVisualization[13345]
#define sipNameNr_MeshSphere 13356
#define sipName_MeshSphere &sipStrings_QtDataVisualization[13356]
#define sipNameNr_Q3DScatter 13367
#define sipName_Q3DScatter &sipStrings_QtDataVisualization[13367]
#define sipNameNr_Q3DSurface 13378
#define sipName_Q3DSurface &sipStrings_QtDataVisualization[13378]
#define sipNameNr_SeriesType 707
#define sipName_SeriesType &sipStrings_QtDataVisualization[707]
#define sipNameNr_ThemeDigia 13389
#define sipName_ThemeDigia &sipStrings_QtDataVisualization[13389]
#define sipNameNr_ThemeEbony 13400
#define sipName_ThemeEbony &sipStrings_QtDataVisualization[13400]
#define sipNameNr_ThemeRetro 13411
#define sipName_ThemeRetro &sipStrings_QtDataVisualization[13411]
#define sipNameNr_arrayReset 13422
#define sipName_arrayReset &sipStrings_QtDataVisualization[13422]
#define sipNameNr_autoScaleY 13433
#define sipName_autoScaleY &sipStrings_QtDataVisualization[13433]
#define sipNameNr_barSpacing 13444
#define sipName_barSpacing &sipStrings_QtDataVisualization[13444]
#define sipNameNr_baseColors 13455
#define sipName_baseColors &sipStrings_QtDataVisualization[13455]
#define sipNameNr_childEvent 13466
#define sipName_childEvent &sipStrings_QtDataVisualization[13466]
#define sipNameNr_closeEvent 13477
#define sipName_closeEvent &sipStrings_QtDataVisualization[13477]
#define sipNameNr_colorStyle 13488
#define sipName_colorStyle &sipStrings_QtDataVisualization[13488]
#define sipNameNr_colorTable 13499
#define sipName_colorTable &sipStrings_QtDataVisualization[13499]
#define sipNameNr_columnAxis 13510
#define sipName_columnAxis &sipStrings_QtDataVisualization[13510]
#define sipNameNr_columnRole 13521
#define sipName_columnRole &sipStrings_QtDataVisualization[13521]
#define sipNameNr_currentFps 13532
#define sipName_currentFps &sipStrings_QtDataVisualization[13532]
#define sipNameNr_drawSlices 13543
#define sipName_drawSlices &sipStrings_QtDataVisualization[13543]
#define sipNameNr_floorLevel 13554
#define sipName_floorLevel &sipStrings_QtDataVisualization[13554]
#define sipNameNr_hasContext 13565
#define sipName_hasContext &sipStrings_QtDataVisualization[13565]
#define sipNameNr_insertItem 13576
#define sipName_insertItem &sipStrings_QtDataVisualization[13576]
#define sipNameNr_insertRows 13587
#define sipName_insertRows &sipStrings_QtDataVisualization[13587]
#define sipNameNr_itemsAdded 13598
#define sipName_itemsAdded &sipStrings_QtDataVisualization[13598]
#define sipNameNr_lightColor 2986
#define sipName_lightColor &sipStrings_QtDataVisualization[2986]
#define sipNameNr_maxChanged 13609
#define sipName_maxChanged &sipStrings_QtDataVisualization[13609]
#define sipNameNr_measureFps 13620
#define sipName_measureFps &sipStrings_QtDataVisualization[13620]
#define sipNameNr_minChanged 13631
#define sipName_minChanged &sipStrings_QtDataVisualization[13631]
#define sipNameNr_paintEvent 13642
#define sipName_paintEvent &sipStrings_QtDataVisualization[13642]
#define sipNameNr_positionAt 13653
#define sipName_positionAt &sipStrings_QtDataVisualization[13653]
#define sipNameNr_removeRows 13664
#define sipName_removeRows &sipStrings_QtDataVisualization[13664]
#define sipNameNr_resetArray 13675
#define sipName_resetArray &sipStrings_QtDataVisualization[13675]
#define sipNameNr_seriesList 13686
#define sipName_seriesList &sipStrings_QtDataVisualization[13686]
#define sipNameNr_setRowAxis 13697
#define sipName_setRowAxis &sipStrings_QtDataVisualization[13697]
#define sipNameNr_setRowRole 13708
#define sipName_setRowRole &sipStrings_QtDataVisualization[13708]
#define sipNameNr_setScaling 13719
#define sipName_setScaling &sipStrings_QtDataVisualization[13719]
#define sipNameNr_setTexture 13730
#define sipName_setTexture &sipStrings_QtDataVisualization[13730]
#define sipNameNr_setVisible 13741
#define sipName_setVisible &sipStrings_QtDataVisualization[13741]
#define sipNameNr_timerEvent 13752
#define sipName_timerEvent &sipStrings_QtDataVisualization[13752]
#define sipNameNr_touchEvent 13763
#define sipName_touchEvent &sipStrings_QtDataVisualization[13763]
#define sipNameNr_wheelEvent 13774
#define sipName_wheelEvent &sipStrings_QtDataVisualization[13774]
#define sipNameNr_InputView 268
#define sipName_InputView &sipStrings_QtDataVisualization[268]
#define sipNameNr_MeshArrow 13785
#define sipName_MeshArrow &sipStrings_QtDataVisualization[13785]
#define sipNameNr_MeshPoint 13795
#define sipName_MeshPoint &sipStrings_QtDataVisualization[13795]
#define sipNameNr_Q3DCamera 13805
#define sipName_Q3DCamera &sipStrings_QtDataVisualization[13805]
#define sipNameNr_Q3DObject 13815
#define sipName_Q3DObject &sipStrings_QtDataVisualization[13815]
#define sipNameNr_addSeries 13825
#define sipName_addSeries &sipStrings_QtDataVisualization[13825]
#define sipNameNr_allowZero 13835
#define sipName_allowZero &sipStrings_QtDataVisualization[13835]
#define sipNameNr_baseColor 13845
#define sipName_baseColor &sipStrings_QtDataVisualization[13845]
#define sipNameNr_dataProxy 13855
#define sipName_dataProxy &sipStrings_QtDataVisualization[13855]
#define sipNameNr_formatter 13865
#define sipName_formatter &sipStrings_QtDataVisualization[13865]
#define sipNameNr_hasSeries 13875
#define sipName_hasSeries &sipStrings_QtDataVisualization[13875]
#define sipNameNr_heightMap 13885
#define sipName_heightMap &sipStrings_QtDataVisualization[13885]
#define sipNameNr_hideEvent 13895
#define sipName_hideEvent &sipStrings_QtDataVisualization[13895]
#define sipNameNr_imageSize 13905
#define sipName_imageSize &sipStrings_QtDataVisualization[13905]
#define sipNameNr_inputView 13915
#define sipName_inputView &sipStrings_QtDataVisualization[13915]
#define sipNameNr_insertRow 13925
#define sipName_insertRow &sipStrings_QtDataVisualization[13925]
#define sipNameNr_isVisible 13935
#define sipName_isVisible &sipStrings_QtDataVisualization[13935]
#define sipNameNr_itemCount 13945
#define sipName_itemCount &sipStrings_QtDataVisualization[13945]
#define sipNameNr_itemLabel 13955
#define sipName_itemLabel &sipStrings_QtDataVisualization[13955]
#define sipNameNr_itemModel 13965
#define sipName_itemModel &sipStrings_QtDataVisualization[13965]
#define sipNameNr_markDirty 13975
#define sipName_markDirty &sipStrings_QtDataVisualization[13975]
#define sipNameNr_maxXValue 13985
#define sipName_maxXValue &sipStrings_QtDataVisualization[13985]
#define sipNameNr_maxYValue 13995
#define sipName_maxYValue &sipStrings_QtDataVisualization[13995]
#define sipNameNr_maxZValue 14005
#define sipName_maxZValue &sipStrings_QtDataVisualization[14005]
#define sipNameNr_meshAngle 14015
#define sipName_meshAngle &sipStrings_QtDataVisualization[14015]
#define sipNameNr_minXValue 14025
#define sipName_minXValue &sipStrings_QtDataVisualization[14025]
#define sipNameNr_minYValue 14035
#define sipName_minYValue &sipStrings_QtDataVisualization[14035]
#define sipNameNr_minZValue 14045
#define sipName_minZValue &sipStrings_QtDataVisualization[14045]
#define sipNameNr_moveEvent 14055
#define sipName_moveEvent &sipStrings_QtDataVisualization[14055]
#define sipNameNr_rowColors 14065
#define sipName_rowColors &sipStrings_QtDataVisualization[14065]
#define sipNameNr_rowLabels 14075
#define sipName_rowLabels &sipStrings_QtDataVisualization[14075]
#define sipNameNr_rowsAdded 14085
#define sipName_rowsAdded &sipStrings_QtDataVisualization[14085]
#define sipNameNr_setLabels 14095
#define sipName_setLabels &sipStrings_QtDataVisualization[14095]
#define sipNameNr_setLocale 14105
#define sipName_setLocale &sipStrings_QtDataVisualization[14105]
#define sipNameNr_setMargin 14115
#define sipName_setMargin &sipStrings_QtDataVisualization[14115]
#define sipNameNr_setTarget 14125
#define sipName_setTarget &sipStrings_QtDataVisualization[14125]
#define sipNameNr_showEvent 14135
#define sipName_showEvent &sipStrings_QtDataVisualization[14135]
#define sipNameNr_textColor 14145
#define sipName_textColor &sipStrings_QtDataVisualization[14145]
#define sipNameNr_valueAxis 14155
#define sipName_valueAxis &sipStrings_QtDataVisualization[14155]
#define sipNameNr_valueRole 14165
#define sipName_valueRole &sipStrings_QtDataVisualization[14165]
#define sipNameNr_xRotation 14175
#define sipName_xRotation &sipStrings_QtDataVisualization[14175]
#define sipNameNr_yRotation 14185
#define sipName_yRotation &sipStrings_QtDataVisualization[14185]
#define sipNameNr_zoomLevel 14195
#define sipName_zoomLevel &sipStrings_QtDataVisualization[14195]
#define sipNameNr_AxisType 1596
#define sipName_AxisType &sipStrings_QtDataVisualization[1596]
#define sipNameNr_DataType 858
#define sipName_DataType &sipStrings_QtDataVisualization[858]
#define sipNameNr_DrawFlag 1304
#define sipName_DrawFlag &sipStrings_QtDataVisualization[1304]
#define sipNameNr_MMBFirst 14205
#define sipName_MMBFirst &sipStrings_QtDataVisualization[14205]
#define sipNameNr_MeshCone 14214
#define sipName_MeshCone &sipStrings_QtDataVisualization[14214]
#define sipNameNr_MeshCube 14223
#define sipName_MeshCube &sipStrings_QtDataVisualization[14223]
#define sipNameNr_Q3DLight 14232
#define sipName_Q3DLight &sipStrings_QtDataVisualization[14232]
#define sipNameNr_Q3DScene 14241
#define sipName_Q3DScene &sipStrings_QtDataVisualization[14241]
#define sipNameNr_Q3DTheme 14250
#define sipName_Q3DTheme &sipStrings_QtDataVisualization[14250]
#define sipNameNr_addItems 14259
#define sipName_addItems &sipStrings_QtDataVisualization[14259]
#define sipNameNr_addTheme 14268
#define sipName_addTheme &sipStrings_QtDataVisualization[14268]
#define sipNameNr_drawMode 14277
#define sipName_drawMode &sipStrings_QtDataVisualization[14277]
#define sipNameNr_itemSize 14286
#define sipName_itemSize &sipStrings_QtDataVisualization[14286]
#define sipNameNr_meshFile 14295
#define sipName_meshFile &sipStrings_QtDataVisualization[14295]
#define sipNameNr_position 14304
#define sipName_position &sipStrings_QtDataVisualization[14304]
#define sipNameNr_reversed 14313
#define sipName_reversed &sipStrings_QtDataVisualization[14313]
#define sipNameNr_rotation 14322
#define sipName_rotation &sipStrings_QtDataVisualization[14322]
#define sipNameNr_rowCount 14331
#define sipName_rowCount &sipStrings_QtDataVisualization[14331]
#define sipNameNr_setAxisX 14340
#define sipName_setAxisX &sipStrings_QtDataVisualization[14340]
#define sipNameNr_setAxisY 14349
#define sipName_setAxisY &sipStrings_QtDataVisualization[14349]
#define sipNameNr_setAxisZ 14358
#define sipName_setAxisZ &sipStrings_QtDataVisualization[14358]
#define sipNameNr_setDirty 14367
#define sipName_setDirty &sipStrings_QtDataVisualization[14367]
#define sipNameNr_setItems 14376
#define sipName_setItems &sipStrings_QtDataVisualization[14376]
#define sipNameNr_setPolar 14385
#define sipName_setPolar &sipStrings_QtDataVisualization[14385]
#define sipNameNr_setRange 14394
#define sipName_setRange &sipStrings_QtDataVisualization[14394]
#define sipNameNr_setScene 14403
#define sipName_setScene &sipStrings_QtDataVisualization[14403]
#define sipNameNr_setTitle 14412
#define sipName_setTitle &sipStrings_QtDataVisualization[14412]
#define sipNameNr_setValue 14421
#define sipName_setValue &sipStrings_QtDataVisualization[14421]
#define sipNameNr_viewport 14430
#define sipName_viewport &sipStrings_QtDataVisualization[14430]
#define sipNameNr_xPosRole 14439
#define sipName_xPosRole &sipStrings_QtDataVisualization[14439]
#define sipNameNr_yPosRole 14448
#define sipName_yPosRole &sipStrings_QtDataVisualization[14448]
#define sipNameNr_zPosRole 14457
#define sipName_zPosRole &sipStrings_QtDataVisualization[14457]
#define sipNameNr_MMBLast 14466
#define sipName_MMBLast &sipStrings_QtDataVisualization[14466]
#define sipNameNr_MeshBar 14474
#define sipName_MeshBar &sipStrings_QtDataVisualization[14474]
#define sipNameNr_Q3DBars 14482
#define sipName_Q3DBars &sipStrings_QtDataVisualization[14482]
#define sipNameNr_ThemeQt 14490
#define sipName_ThemeQt &sipStrings_QtDataVisualization[14490]
#define sipNameNr_addAxis 14498
#define sipName_addAxis &sipStrings_QtDataVisualization[14498]
#define sipNameNr_addItem 14506
#define sipName_addItem &sipStrings_QtDataVisualization[14506]
#define sipNameNr_addRows 14514
#define sipName_addRows &sipStrings_QtDataVisualization[14514]
#define sipNameNr_isDirty 14522
#define sipName_isDirty &sipStrings_QtDataVisualization[14522]
#define sipNameNr_isPolar 14530
#define sipName_isPolar &sipStrings_QtDataVisualization[14530]
#define sipNameNr_rowAxis 14538
#define sipName_rowAxis &sipStrings_QtDataVisualization[14538]
#define sipNameNr_rowRole 14546
#define sipName_rowRole &sipStrings_QtDataVisualization[14546]
#define sipNameNr_scaling 14554
#define sipName_scaling &sipStrings_QtDataVisualization[14554]
#define sipNameNr_setBase 14562
#define sipName_setBase &sipStrings_QtDataVisualization[14562]
#define sipNameNr_setFont 14570
#define sipName_setFont &sipStrings_QtDataVisualization[14570]
#define sipNameNr_setItem 14578
#define sipName_setItem &sipStrings_QtDataVisualization[14578]
#define sipNameNr_setMesh 14586
#define sipName_setMesh &sipStrings_QtDataVisualization[14586]
#define sipNameNr_setName 14594
#define sipName_setName &sipStrings_QtDataVisualization[14594]
#define sipNameNr_setRows 14602
#define sipName_setRows &sipStrings_QtDataVisualization[14602]
#define sipNameNr_setText 14610
#define sipName_setText &sipStrings_QtDataVisualization[14610]
#define sipNameNr_setType 14618
#define sipName_setType &sipStrings_QtDataVisualization[14618]
#define sipNameNr_texture 14626
#define sipName_texture &sipStrings_QtDataVisualization[14626]
#define sipNameNr_valueAt 14634
#define sipName_valueAt &sipStrings_QtDataVisualization[14634]
#define sipNameNr_addRow 14642
#define sipName_addRow &sipStrings_QtDataVisualization[14642]
#define sipNameNr_format 14649
#define sipName_format &sipStrings_QtDataVisualization[14649]
#define sipNameNr_itemAt 14656
#define sipName_itemAt &sipStrings_QtDataVisualization[14656]
#define sipNameNr_labels 14663
#define sipName_labels &sipStrings_QtDataVisualization[14663]
#define sipNameNr_locale 14670
#define sipName_locale &sipStrings_QtDataVisualization[14670]
#define sipNameNr_margin 14677
#define sipName_margin &sipStrings_QtDataVisualization[14677]
#define sipNameNr_parent 14684
#define sipName_parent &sipStrings_QtDataVisualization[14684]
#define sipNameNr_series 14691
#define sipName_series &sipStrings_QtDataVisualization[14691]
#define sipNameNr_setMax 14698
#define sipName_setMax &sipStrings_QtDataVisualization[14698]
#define sipNameNr_setMin 14705
#define sipName_setMin &sipStrings_QtDataVisualization[14705]
#define sipNameNr_setRow 14712
#define sipName_setRow &sipStrings_QtDataVisualization[14712]
#define sipNameNr_target 14719
#define sipName_target &sipStrings_QtDataVisualization[14719]
#define sipNameNr_themes 14726
#define sipName_themes &sipStrings_QtDataVisualization[14726]
#define sipNameNr_Theme 9506
#define sipName_Theme &sipStrings_QtDataVisualization[9506]
#define sipNameNr_array 14733
#define sipName_array &sipStrings_QtDataVisualization[14733]
#define sipNameNr_axisX 14739
#define sipName_axisX &sipStrings_QtDataVisualization[14739]
#define sipNameNr_axisY 14745
#define sipName_axisY &sipStrings_QtDataVisualization[14745]
#define sipNameNr_axisZ 14751
#define sipName_axisZ &sipStrings_QtDataVisualization[14751]
#define sipNameNr_event 14757
#define sipName_event &sipStrings_QtDataVisualization[14757]
#define sipNameNr_remap 14763
#define sipName_remap &sipStrings_QtDataVisualization[14763]
#define sipNameNr_rowAt 14769
#define sipName_rowAt &sipStrings_QtDataVisualization[14769]
#define sipNameNr_scene 14775
#define sipName_scene &sipStrings_QtDataVisualization[14775]
#define sipNameNr_title 14781
#define sipName_title &sipStrings_QtDataVisualization[14781]
#define sipNameNr_value 14787
#define sipName_value &sipStrings_QtDataVisualization[14787]
#define sipNameNr_Mesh 2584
#define sipName_Mesh &sipStrings_QtDataVisualization[2584]
#define sipNameNr_axes 14793
#define sipName_axes &sipStrings_QtDataVisualization[14793]
#define sipNameNr_axis 14798
#define sipName_axis &sipStrings_QtDataVisualization[14798]
#define sipNameNr_base 14803
#define sipName_base &sipStrings_QtDataVisualization[14803]
#define sipNameNr_font 14808
#define sipName_font &sipStrings_QtDataVisualization[14808]
#define sipNameNr_mesh 14813
#define sipName_mesh &sipStrings_QtDataVisualization[14813]
#define sipNameNr_name 14818
#define sipName_name &sipStrings_QtDataVisualization[14818]
#define sipNameNr_setX 14823
#define sipName_setX &sipStrings_QtDataVisualization[14823]
#define sipNameNr_setY 14828
#define sipName_setY &sipStrings_QtDataVisualization[14828]
#define sipNameNr_setZ 14833
#define sipName_setZ &sipStrings_QtDataVisualization[14833]
#define sipNameNr_size 14838
#define sipName_size &sipStrings_QtDataVisualization[14838]
#define sipNameNr_text 13571
#define sipName_text &sipStrings_QtDataVisualization[13571]
#define sipNameNr_type 14843
#define sipName_type &sipStrings_QtDataVisualization[14843]
#define sipNameNr_zoom 14848
#define sipName_zoom &sipStrings_QtDataVisualization[14848]
#define sipNameNr_max 14853
#define sipName_max &sipStrings_QtDataVisualization[14853]
#define sipNameNr_min 14857
#define sipName_min &sipStrings_QtDataVisualization[14857]
#define sipNameNr_x 2827
#define sipName_x &sipStrings_QtDataVisualization[2827]
#define sipNameNr_y 408
#define sipName_y &sipStrings_QtDataVisualization[408]
#define sipNameNr_z 14861
#define sipName_z &sipStrings_QtDataVisualization[14861]

#define sipMalloc                   sipAPI_QtDataVisualization->api_malloc
#define sipFree                     sipAPI_QtDataVisualization->api_free
#define sipBuildResult              sipAPI_QtDataVisualization->api_build_result
#define sipCallMethod               sipAPI_QtDataVisualization->api_call_method
#define sipCallProcedureMethod      sipAPI_QtDataVisualization->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtDataVisualization->api_call_error_handler
#define sipParseResultEx            sipAPI_QtDataVisualization->api_parse_result_ex
#define sipParseResult              sipAPI_QtDataVisualization->api_parse_result
#define sipParseArgs                sipAPI_QtDataVisualization->api_parse_args
#define sipParseKwdArgs             sipAPI_QtDataVisualization->api_parse_kwd_args
#define sipParsePair                sipAPI_QtDataVisualization->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtDataVisualization->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtDataVisualization->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtDataVisualization->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtDataVisualization->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtDataVisualization->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtDataVisualization->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtDataVisualization->api_add_exception
#define sipNoFunction               sipAPI_QtDataVisualization->api_no_function
#define sipNoMethod                 sipAPI_QtDataVisualization->api_no_method
#define sipAbstractMethod           sipAPI_QtDataVisualization->api_abstract_method
#define sipBadClass                 sipAPI_QtDataVisualization->api_bad_class
#define sipBadCatcherResult         sipAPI_QtDataVisualization->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtDataVisualization->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtDataVisualization->api_bad_operator_arg
#define sipTrace                    sipAPI_QtDataVisualization->api_trace
#define sipTransferBack             sipAPI_QtDataVisualization->api_transfer_back
#define sipTransferTo               sipAPI_QtDataVisualization->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtDataVisualization->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtDataVisualization->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtDataVisualization->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtDataVisualization->api_voidptr_type
#define sipGetPyObject              sipAPI_QtDataVisualization->api_get_pyobject
#define sipGetAddress               sipAPI_QtDataVisualization->api_get_address
#define sipGetMixinAddress          sipAPI_QtDataVisualization->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtDataVisualization->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtDataVisualization->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtDataVisualization->api_call_hook
#define sipEndThread                sipAPI_QtDataVisualization->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtDataVisualization->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtDataVisualization->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtDataVisualization->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtDataVisualization->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtDataVisualization->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtDataVisualization->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtDataVisualization->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtDataVisualization->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtDataVisualization->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtDataVisualization->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtDataVisualization->api_convert_to_bool
#define sipReleaseType              sipAPI_QtDataVisualization->api_release_type
#define sipConvertFromType          sipAPI_QtDataVisualization->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtDataVisualization->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtDataVisualization->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtDataVisualization->api_convert_from_enum
#define sipGetState                 sipAPI_QtDataVisualization->api_get_state
#define sipExportSymbol             sipAPI_QtDataVisualization->api_export_symbol
#define sipImportSymbol             sipAPI_QtDataVisualization->api_import_symbol
#define sipFindType                 sipAPI_QtDataVisualization->api_find_type
#define sipBytes_AsChar             sipAPI_QtDataVisualization->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtDataVisualization->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtDataVisualization->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtDataVisualization->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtDataVisualization->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtDataVisualization->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtDataVisualization->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtDataVisualization->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtDataVisualization->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtDataVisualization->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtDataVisualization->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtDataVisualization->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtDataVisualization->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtDataVisualization->api_get_reference
#define sipKeepReference            sipAPI_QtDataVisualization->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtDataVisualization->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtDataVisualization->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtDataVisualization->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtDataVisualization->api_type_scope
#define sipResolveTypedef           sipAPI_QtDataVisualization->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtDataVisualization->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtDataVisualization->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtDataVisualization->api_init_mixin
#define sipExportModule             sipAPI_QtDataVisualization->api_export_module
#define sipInitModule               sipAPI_QtDataVisualization->api_init_module
#define sipGetInterpreter           sipAPI_QtDataVisualization->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtDataVisualization->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtDataVisualization->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtDataVisualization->api_py_type_dict
#define sipPyTypeName               sipAPI_QtDataVisualization->api_py_type_name
#define sipGetCFunction             sipAPI_QtDataVisualization->api_get_c_function
#define sipGetMethod                sipAPI_QtDataVisualization->api_get_method
#define sipFromMethod               sipAPI_QtDataVisualization->api_from_method
#define sipGetDate                  sipAPI_QtDataVisualization->api_get_date
#define sipFromDate                 sipAPI_QtDataVisualization->api_from_date
#define sipGetDateTime              sipAPI_QtDataVisualization->api_get_datetime
#define sipFromDateTime             sipAPI_QtDataVisualization->api_from_datetime
#define sipGetTime                  sipAPI_QtDataVisualization->api_get_time
#define sipFromTime                 sipAPI_QtDataVisualization->api_from_time
#define sipIsUserType               sipAPI_QtDataVisualization->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtDataVisualization->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtDataVisualization->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtDataVisualization->api_unicode_write
#define sipUnicodeData              sipAPI_QtDataVisualization->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtDataVisualization->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtDataVisualization->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtDataVisualization->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtDataVisualization->api_is_derived_class
#define sipGetUserObject            sipAPI_QtDataVisualization->api_get_user_object
#define sipSetUserObject            sipAPI_QtDataVisualization->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtDataVisualization->api_register_event_handler
#define sipConvertToArray           sipAPI_QtDataVisualization->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtDataVisualization->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtDataVisualization->api_enable_gc
#define sipPrintObject              sipAPI_QtDataVisualization->api_print_object
#define sipLong_AsChar              sipAPI_QtDataVisualization->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtDataVisualization->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtDataVisualization->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtDataVisualization->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtDataVisualization->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtDataVisualization->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtDataVisualization->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtDataVisualization->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtDataVisualization->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtDataVisualization->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtDataVisualization->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtDataVisualization->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtDataVisualization->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtDataVisualization->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtDataVisualization->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtDataVisualization->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtDataVisualization->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtDataVisualization->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtDataVisualization->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtDataVisualization->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtDataVisualization->api_release_type_us
#define sipIsPyMethod               sipAPI_QtDataVisualization->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtDataVisualization[];

#define sipType_QAbstract3DGraph sipExportedTypes_QtDataVisualization[15]

#define sipType_QAbstract3DGraph_OptimizationHint sipExportedTypes_QtDataVisualization[17]

#define sipType_QAbstract3DGraph_ElementType sipExportedTypes_QtDataVisualization[16]

#define sipType_QAbstract3DGraph_ShadowQuality sipExportedTypes_QtDataVisualization[19]

#define sipType_QAbstract3DGraph_SelectionFlag sipExportedTypes_QtDataVisualization[18]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QAbstract3DGraph;

#define sipType_Q3DBars sipExportedTypes_QtDataVisualization[0]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DBars;

#define sipType_Q3DObject sipExportedTypes_QtDataVisualization[5]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DObject;

#define sipType_Q3DCamera sipExportedTypes_QtDataVisualization[1]

#define sipType_Q3DCamera_CameraPreset sipExportedTypes_QtDataVisualization[2]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DCamera;

#define sipType_QAbstract3DInputHandler sipExportedTypes_QtDataVisualization[20]

#define sipType_QAbstract3DInputHandler_InputView sipExportedTypes_QtDataVisualization[21]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QAbstract3DInputHandler;

#define sipType_Q3DInputHandler sipExportedTypes_QtDataVisualization[3]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DInputHandler;

#define sipType_Q3DLight sipExportedTypes_QtDataVisualization[4]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DLight;

#define sipType_Q3DScatter sipExportedTypes_QtDataVisualization[6]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DScatter;

#define sipType_Q3DScene sipExportedTypes_QtDataVisualization[7]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DScene;

#define sipType_Q3DSurface sipExportedTypes_QtDataVisualization[8]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DSurface;

#define sipType_Q3DTheme sipExportedTypes_QtDataVisualization[9]

#define sipType_Q3DTheme_Theme sipExportedTypes_QtDataVisualization[11]

#define sipType_Q3DTheme_ColorStyle sipExportedTypes_QtDataVisualization[10]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DTheme;

#define sipType_QAbstract3DAxis sipExportedTypes_QtDataVisualization[12]

#define sipType_QAbstract3DAxis_AxisType sipExportedTypes_QtDataVisualization[14]

#define sipType_QAbstract3DAxis_AxisOrientation sipExportedTypes_QtDataVisualization[13]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QAbstract3DAxis;

#define sipType_QAbstract3DSeries sipExportedTypes_QtDataVisualization[22]

#define sipType_QAbstract3DSeries_Mesh sipExportedTypes_QtDataVisualization[23]

#define sipType_QAbstract3DSeries_SeriesType sipExportedTypes_QtDataVisualization[24]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QAbstract3DSeries;

#define sipType_QAbstractDataProxy sipExportedTypes_QtDataVisualization[25]

#define sipType_QAbstractDataProxy_DataType sipExportedTypes_QtDataVisualization[26]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QAbstractDataProxy;

#define sipType_QBar3DSeries sipExportedTypes_QtDataVisualization[27]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QBar3DSeries;

#define sipType_QBarDataItem sipExportedTypes_QtDataVisualization[28]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QBarDataItem;

#define sipType_QBarDataProxy sipExportedTypes_QtDataVisualization[29]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QBarDataProxy;

#define sipType_QCategory3DAxis sipExportedTypes_QtDataVisualization[30]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QCategory3DAxis;

#define sipType_QCustom3DItem sipExportedTypes_QtDataVisualization[31]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QCustom3DItem;

#define sipType_QCustom3DLabel sipExportedTypes_QtDataVisualization[32]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QCustom3DLabel;

#define sipType_QCustom3DVolume sipExportedTypes_QtDataVisualization[33]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QCustom3DVolume;

#define sipType_QSurfaceDataProxy sipExportedTypes_QtDataVisualization[67]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QSurfaceDataProxy;

#define sipType_QHeightMapSurfaceDataProxy sipExportedTypes_QtDataVisualization[37]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QHeightMapSurfaceDataProxy;

#define sipType_QItemModelBarDataProxy sipExportedTypes_QtDataVisualization[38]

#define sipType_QItemModelBarDataProxy_MultiMatchBehavior sipExportedTypes_QtDataVisualization[39]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QItemModelBarDataProxy;

#define sipType_QScatterDataProxy sipExportedTypes_QtDataVisualization[63]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QScatterDataProxy;

#define sipType_QItemModelScatterDataProxy sipExportedTypes_QtDataVisualization[40]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QItemModelScatterDataProxy;

#define sipType_QItemModelSurfaceDataProxy sipExportedTypes_QtDataVisualization[41]

#define sipType_QItemModelSurfaceDataProxy_MultiMatchBehavior sipExportedTypes_QtDataVisualization[42]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QItemModelSurfaceDataProxy;

#define sipType_QValue3DAxisFormatter sipExportedTypes_QtDataVisualization[70]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QValue3DAxisFormatter;

#define sipType_QLogValue3DAxisFormatter sipExportedTypes_QtDataVisualization[60]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QLogValue3DAxisFormatter;

#define sipType_QScatter3DSeries sipExportedTypes_QtDataVisualization[61]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QScatter3DSeries;

#define sipType_QScatterDataItem sipExportedTypes_QtDataVisualization[62]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QScatterDataItem;

#define sipType_QSurface3DSeries sipExportedTypes_QtDataVisualization[64]

#define sipType_QSurface3DSeries_DrawFlag sipExportedTypes_QtDataVisualization[65]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QSurface3DSeries;

#define sipType_QSurfaceDataItem sipExportedTypes_QtDataVisualization[66]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QSurfaceDataItem;

#define sipType_QTouch3DInputHandler sipExportedTypes_QtDataVisualization[68]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QTouch3DInputHandler;

#define sipType_QValue3DAxis sipExportedTypes_QtDataVisualization[69]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QValue3DAxis;

#define sipType_QList_0100QLinearGradient sipExportedTypes_QtDataVisualization[51]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QLinearGradient;

#define sipType_QList_0100QColor sipExportedTypes_QtDataVisualization[48]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QColor;

#define sipType_QList_0101QSurface3DSeries sipExportedTypes_QtDataVisualization[56]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QSurface3DSeries;

#define sipType_QList_0101QValue3DAxis sipExportedTypes_QtDataVisualization[58]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QValue3DAxis;

#define sipType_QList_0101QScatter3DSeries sipExportedTypes_QtDataVisualization[54]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QScatter3DSeries;

#define sipType_QList_0101QAbstract3DAxis sipExportedTypes_QtDataVisualization[44]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QAbstract3DAxis;

#define sipType_QList_0101QBar3DSeries sipExportedTypes_QtDataVisualization[46]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QBar3DSeries;

#define sipType_QList_0101QCustom3DItem sipExportedTypes_QtDataVisualization[49]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QCustom3DItem;

#define sipType_QList_0101Q3DTheme sipExportedTypes_QtDataVisualization[43]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101Q3DTheme;

#define sipType_QList_0101QAbstract3DInputHandler sipExportedTypes_QtDataVisualization[45]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QAbstract3DInputHandler;

#define sipType_QList_0100QSurfaceDataItem sipExportedTypes_QtDataVisualization[57]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QSurfaceDataItem;

#define sipType_QList_0601QList_0100QSurfaceDataItem sipExportedTypes_QtDataVisualization[53]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0601QList_0100QSurfaceDataItem;

#define sipType_QFlags_0100QSurface3DSeries_DrawFlag sipExportedTypes_QtDataVisualization[36]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QFlags_0100QSurface3DSeries_DrawFlag;

#define sipType_QList_0100QScatterDataItem sipExportedTypes_QtDataVisualization[55]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QScatterDataItem;

#define sipType_QList_0100QBarDataItem sipExportedTypes_QtDataVisualization[47]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QBarDataItem;

#define sipType_QList_0601QList_0100QBarDataItem sipExportedTypes_QtDataVisualization[52]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0601QList_0100QBarDataItem;

#define sipType_QFlags_0100QAbstract3DGraph_SelectionFlag sipExportedTypes_QtDataVisualization[35]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QFlags_0100QAbstract3DGraph_SelectionFlag;

#define sipType_QFlags_0100QAbstract3DGraph_OptimizationHint sipExportedTypes_QtDataVisualization[34]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QFlags_0100QAbstract3DGraph_OptimizationHint;

#define sipType_QList_1300 sipExportedTypes_QtDataVisualization[59]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_1300;

#define sipType_QList_0101QImage sipExportedTypes_QtDataVisualization[50]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QImage;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtDataVisualization;
extern sipExportedModuleDef sipModuleAPI_QtDataVisualization;
extern sipTypeDef *sipExportedTypes_QtDataVisualization[];

#define sipType_Qt_Axis sipImportedTypes_QtDataVisualization_QtCore[17].it_td

#define sipType_QObject sipImportedTypes_QtDataVisualization_QtCore[8].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtDataVisualization_QtCore[0].it_td

#define sipType_QByteArray sipImportedTypes_QtDataVisualization_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtDataVisualization_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtDataVisualization_QtCore[16].it_td

#define sipType_QChildEvent sipImportedTypes_QtDataVisualization_QtCore[2].it_td

#define sipType_QLocale sipImportedTypes_QtDataVisualization_QtCore[6].it_td

#define sipType_QMetaMethod sipImportedTypes_QtDataVisualization_QtCore[7].it_td

#define sipType_QPoint sipImportedTypes_QtDataVisualization_QtCore[9].it_td

#define sipType_QRect sipImportedTypes_QtDataVisualization_QtCore[10].it_td

#define sipType_QRegularExpression sipImportedTypes_QtDataVisualization_QtCore[11].it_td

#define sipType_QSize sipImportedTypes_QtDataVisualization_QtCore[12].it_td

#define sipType_QSizeF sipImportedTypes_QtDataVisualization_QtCore[13].it_td

#define sipType_QStringList sipImportedTypes_QtDataVisualization_QtCore[15].it_td

#define sipType_QList_2200 sipImportedTypes_QtDataVisualization_QtCore[4].it_td

#define sipType_QList_1900 sipImportedTypes_QtDataVisualization_QtCore[5].it_td

#define sipType_QString sipImportedTypes_QtDataVisualization_QtCore[14].it_td

#define sipType_qintptr sipImportedTypes_QtDataVisualization_QtCore[18].it_td
extern sipImportedTypeDef sipImportedTypes_QtDataVisualization_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[];

#define sipType_QColor sipImportedTypes_QtDataVisualization_QtGui[1].it_td

#define sipType_QLinearGradient sipImportedTypes_QtDataVisualization_QtGui[9].it_td

#define sipType_QKeyEvent sipImportedTypes_QtDataVisualization_QtGui[8].it_td

#define sipType_QFocusEvent sipImportedTypes_QtDataVisualization_QtGui[3].it_td

#define sipType_QPaintEvent sipImportedTypes_QtDataVisualization_QtGui[12].it_td

#define sipType_QMoveEvent sipImportedTypes_QtDataVisualization_QtGui[11].it_td

#define sipType_QResizeEvent sipImportedTypes_QtDataVisualization_QtGui[14].it_td

#define sipType_QCloseEvent sipImportedTypes_QtDataVisualization_QtGui[0].it_td

#define sipType_QShowEvent sipImportedTypes_QtDataVisualization_QtGui[15].it_td

#define sipType_QHideEvent sipImportedTypes_QtDataVisualization_QtGui[5].it_td

#define sipType_QExposeEvent sipImportedTypes_QtDataVisualization_QtGui[2].it_td

#define sipType_QMouseEvent sipImportedTypes_QtDataVisualization_QtGui[10].it_td

#define sipType_QWheelEvent sipImportedTypes_QtDataVisualization_QtGui[22].it_td

#define sipType_QTabletEvent sipImportedTypes_QtDataVisualization_QtGui[19].it_td

#define sipType_QTouchEvent sipImportedTypes_QtDataVisualization_QtGui[20].it_td

#define sipType_QFont sipImportedTypes_QtDataVisualization_QtGui[4].it_td

#define sipType_QImage sipImportedTypes_QtDataVisualization_QtGui[6].it_td

#define sipType_QImage_Format sipImportedTypes_QtDataVisualization_QtGui[7].it_td

#define sipType_QSurface sipImportedTypes_QtDataVisualization_QtGui[16].it_td

#define sipType_QSurface_SurfaceType sipImportedTypes_QtDataVisualization_QtGui[17].it_td

#define sipType_QWindow sipImportedTypes_QtDataVisualization_QtGui[23].it_td

#define sipType_QQuaternion sipImportedTypes_QtDataVisualization_QtGui[13].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtDataVisualization_QtGui[18].it_td

#define sipType_QVector3D sipImportedTypes_QtDataVisualization_QtGui[21].it_td
extern sipImportedTypeDef sipImportedTypes_QtDataVisualization_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtDataVisualization_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtDataVisualization_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtDataVisualization_qt_metacast;

#endif
